@@ -4,7 +4,7 @@
 
 #include <X11/Xatom.h>
 #include <X11/cursorfont.h>
-#ifdef SHAPE
+#ifdef USE_XSHAPE
 #include <X11/extensions/shape.h>
 #endif
 
@@ -132,6 +132,10 @@ static WMData *convertSelection(WMView * view, Atom selection, Atom target, void
 	WMData *data;
 	char *typeName;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) selection;
+	(void) cdata;
+
 	scr = W_VIEW_SCREEN(view);
 	typeName = XGetAtomName(scr->display, target);
 
@@ -151,11 +155,22 @@ static WMData *convertSelection(WMView * view, Atom selection, Atom target, void
 
 static void selectionLost(WMView * view, Atom selection, void *cdata)
 {
-	wwarning("DND selection lost during drag operation...");
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) view;
+	(void) selection;
+	(void) cdata;
+
+	wwarning(_("XDND selection lost during drag operation..."));
 }
 
 static void selectionDone(WMView * view, Atom selection, Atom target, void *cdata)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) view;
+	(void) selection;
+	(void) target;
+	(void) cdata;
+
 #ifdef XDND_DEBUG
 	printf("selection done\n");
 #endif
@@ -171,29 +186,25 @@ static Window makeDragIcon(WMScreen * scr, WMPixmap * pixmap)
 	WMSize size;
 	unsigned long flags;
 	XSetWindowAttributes attribs;
-	Pixmap pix, mask;
 
 	if (!pixmap) {
 		pixmap = scr->defaultObjectIcon;
 	}
 
 	size = WMGetPixmapSize(pixmap);
-	pix = pixmap->pixmap;
-	mask = pixmap->mask;
 
 	flags = CWSaveUnder | CWBackPixmap | CWOverrideRedirect | CWColormap;
 	attribs.save_under = True;
-	attribs.background_pixmap = pix;
+	attribs.background_pixmap = pixmap->pixmap;
 	attribs.override_redirect = True;
 	attribs.colormap = scr->colormap;
 
 	window = XCreateWindow(scr->display, scr->rootWin, 0, 0, size.width,
 			       size.height, 0, scr->depth, InputOutput, scr->visual, flags, &attribs);
 
-#ifdef SHAPE
-
-	if (mask) {
-		XShapeCombineMask(scr->display, window, ShapeBounding, 0, 0, mask, ShapeSet);
+#ifdef USE_XSHAPE
+	if (pixmap->mask) {
+		XShapeCombineMask(scr->display, window, ShapeBounding, 0, 0, pixmap->mask, ShapeSet);
 	}
 #endif
 
@@ -542,11 +553,17 @@ static void initSourceDragInfo(WMView * sourceView, WMDraggingInfo * info)
  */
 static WMArray *defDropDataTypes(WMView * self)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	return NULL;
 }
 
 static WMDragOperationType defWantedDropOperation(WMView * self)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	return WDOperationNone;
 }
 
@@ -560,15 +577,26 @@ static WMDragOperationType defWantedDropOperation(WMView * self)
 
 static Bool defAcceptDropOperation(WMView * self, WMDragOperationType allowedOperation)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+	(void) allowedOperation;
+
 	return False;
 }
 
 static void defBeganDrag(WMView * self, WMPoint * point)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+	(void) point;
 }
 
 static void defEndedDrag(WMView * self, WMPoint * point, Bool deposited)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+	(void) point;
+	(void) deposited;
 }
 
 /*
@@ -576,6 +604,10 @@ static void defEndedDrag(WMView * self, WMPoint * point, Bool deposited)
  */
 static WMData *defFetchDragData(WMView * self, char *type)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+	(void) type;
+
 	return NULL;
 }
 
@@ -723,7 +755,7 @@ static void storeDestinationProtocolVersion(WMDraggingInfo * info)
 		XFree(winXdndVersion);
 	} else {
 		XDND_DEST_VERSION(info) = 0;
-		wwarning("failed to read XDND version of drop target");
+		wwarning(_("could not get XDND version for target of drop"));
 	}
 }
 
@@ -739,7 +771,7 @@ static void initMotionProcess(WMView * view, WMDraggingInfo * info, XEvent * eve
 	XDND_TIMESTAMP(info) = event->xmotion.time;
 
 	if (!WMCreateSelectionHandler(view, scr->xdndSelectionAtom, CurrentTime, XDND_SELECTION_PROCS(info), NULL)) {
-		wwarning("could not get ownership or DND selection");
+		wwarning(_("could not get ownership of XDND selection"));
 		return;
 	}
 
@@ -1035,7 +1067,7 @@ static void dragSourceResponseTimeOut(void *source)
 	WMView *view = (WMView *) source;
 	WMDraggingInfo *info = &(W_VIEW_SCREEN(view)->dragInfo);
 
-	wwarning("delay for drag destination response expired");
+	wwarning(_("delay for drag destination response expired"));
 	sendLeaveMessage(info);
 
 	recolorCursor(info, False);
