@@ -93,16 +93,16 @@ static int closestListItem(WMList * list, const char *text, Bool exact)
 {
 	WMListItem *item;
 	WMArray *items = WMGetListItems(list);
-	int i, len = strlen(text);
+	int i, nb_item, len = strlen(text);
 
 	if (len == 0)
 		return -1;
 
-	for (i = 0; i < WMGetArrayItemCount(items); i++) {
+	nb_item = WMGetArrayItemCount(items);
+	for (i = 0; i < nb_item; i++) {
 		item = WMGetFromArray(items, i);
-		if (strlen(item->text) >= len &&
-		    ((exact && strcmp(item->text, text) == 0) ||
-		     (!exact && strncmp(item->text, text, len) == 0))) {
+		if ((exact && strcmp(item->text, text) == 0) ||
+			 (!exact && strncmp(item->text, text, len) == 0)) {
 			return i;
 		}
 	}
@@ -470,11 +470,6 @@ static char *get_name_from_path(const char *path)
 	return wstrdup(&(path[size]));
 }
 
-static Bool filterFileName(WMFilePanel * panel, const char *file, Bool isDirectory)
-{
-	return True;
-}
-
 #define CAST(item) (*((WMListItem**)item))
 static int comparer(const void *a, const void *b)
 {
@@ -535,9 +530,7 @@ static void listDirectoryOnColumn(WMFilePanel * panel, int column, const char *p
 			int isDirectory;
 
 			isDirectory = S_ISDIR(stat_buf.st_mode);
-
-			if (filterFileName(panel, dentry->d_name, isDirectory))
-				WMInsertBrowserItem(bPtr, column, -1, dentry->d_name, isDirectory);
+			WMInsertBrowserItem(bPtr, column, -1, dentry->d_name, isDirectory);
 		}
 	}
 	WMSortBrowserColumnWithComparer(bPtr, column, comparer);
@@ -551,6 +544,10 @@ static void fillColumn(WMBrowserDelegate * self, WMBrowser * bPtr, int column, W
 	char *path;
 	WMFilePanel *panel;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+	(void) list;
+
 	if (column > 0) {
 		path = WMGetBrowserPathToColumn(bPtr, column - 1);
 	} else {
@@ -566,6 +563,9 @@ static void browserDClick(WMWidget *widget, void *p_panel)
 {
 	WMFilePanel *panel = p_panel;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) widget;
+
 	WMPerformButtonClick(panel->okButton);
 }
 
@@ -604,6 +604,9 @@ static void createDir(WMWidget *widget, void *p_panel)
 	size_t slen;
 	WMScreen *scr = WMWidgetScreen(panel->win);
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) widget;
+
 	dirName = WMRunInputPanel(scr, panel->win, _("Create Directory"),
 				  _("Enter directory name"), "", _("OK"), _("Cancel"));
 	if (!dirName)
@@ -683,29 +686,38 @@ static void normalizePath(char *s)
 static void deleteFile(WMWidget *widget, void *p_panel)
 {
 	WMFilePanel *panel = p_panel;
-	char *file, *buffer;
+	char *file;
+	char buffer[512];
 	struct stat filestat;
 	WMScreen *scr = WMWidgetScreen(panel->win);
-#define __msgbufsize__ 512
 
-	buffer = wmalloc(__msgbufsize__);
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) widget;
+
 	file = getCurrentFileName(panel);
+	if (file == NULL)
+		return;
+
 	normalizePath(file);
 
 	if (stat(file, &filestat) == -1) {
-		snprintf(buffer, __msgbufsize__, _("Can not find %s: %s"), file, strerror(errno));
+		snprintf(buffer, sizeof(buffer),
+		         _("Can not find %s: %s"),
+		         file, strerror(errno));
 		showError(scr, panel->win, buffer, NULL);
 		goto out;
 	}
 
-	snprintf(buffer, __msgbufsize__, _("Delete %s %s?"),
+	snprintf(buffer, sizeof(buffer), _("Delete %s %s?"),
 		S_ISDIR(filestat.st_mode) ? _("directory") : _("file"), file);
 
 	if (!WMRunAlertPanel(WMWidgetScreen(panel->win), panel->win,
 			     _("Warning"), buffer, _("OK"), _("Cancel"), NULL)) {
 
 		if (remove(file) == -1) {
-			snprintf(buffer, __msgbufsize__, _("Removing %s failed: %s"), file, strerror(errno));
+			snprintf(buffer, sizeof(buffer),
+			         _("Removing %s failed: %s"),
+			         file, strerror(errno));
 			showError(scr, panel->win, buffer, NULL);
 		} else {
 			char *s = strrchr(file, '/');
@@ -716,15 +728,14 @@ static void deleteFile(WMWidget *widget, void *p_panel)
 
 	}
 out:
-	if (buffer)
-		wfree(buffer);
-	if (file)
-		wfree(file);
-#undef __msgbufsize__
+	wfree(file);
 }
 
 static void goUnmount(WMWidget *widget, void *p_panel)
 {
+	/* Not implemented yet */
+	(void) widget;
+	(void) p_panel;
 }
 
 static void goFloppy(WMWidget *widget, void *p_panel)
@@ -733,8 +744,11 @@ static void goFloppy(WMWidget *widget, void *p_panel)
 	struct stat filestat;
 	WMScreen *scr = WMWidgetScreen(panel->win);
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) widget;
+
 	if (stat(WINGsConfiguration.floppyPath, &filestat)) {
-		showError(scr, panel->win, _("An error occured browsing '%s'."), WINGsConfiguration.floppyPath);
+		showError(scr, panel->win, _("An error occurred browsing '%s'."), WINGsConfiguration.floppyPath);
 		return;
 	} else if (!S_ISDIR(filestat.st_mode)) {
 		showError(scr, panel->win, _("'%s' is not a directory."), WINGsConfiguration.floppyPath);
@@ -749,6 +763,9 @@ static void goHome(WMWidget *widget, void *p_panel)
 	WMFilePanel *panel = p_panel;
 	char *home;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) widget;
+
 	/* home is statically allocated. Don't free it! */
 	home = wgethomedir();
 	if (!home)
@@ -808,23 +825,14 @@ static char *getCurrentFileName(WMFilePanel * panel)
 	slen = strlen(path) + strlen(file) + 1;
 	ret = wmalloc(slen);
 
-	if (*file != '/' &&
-	    wstrlcat(ret, path, slen) >= slen)
-		goto error;
+	if (file[0] != '/')
+		strcpy(ret, path);
 
-	if (wstrlcat(ret, file, slen) >= slen)
-		goto error;
+	strcat(ret, file);
 
 	wfree(file);
 	wfree(path);
 	return ret;
-
-error:
-	wfree(file);
-	wfree(path);
-	wfree(ret);
-
-	return NULL;
 }
 
 
