@@ -68,7 +68,7 @@ static void didResizeList(W_ViewDelegate * self, WMView * view);
 
 static void unselectAllListItems(WMList * lPtr, WMListItem * exceptThis);
 
-W_ViewDelegate _ListViewDelegate = {
+static W_ViewDelegate _ListViewDelegate = {
 	NULL,
 	NULL,
 	didResizeList,
@@ -92,6 +92,9 @@ static void updateDoubleBufferPixmap(WMList * lPtr)
 
 static void realizeObserver(void *self, WMNotification * not)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) not;
+
 	updateDoubleBufferPixmap(self);
 }
 
@@ -1100,6 +1103,9 @@ static void didResizeList(W_ViewDelegate * self, WMView * view)
 {
 	WMList *lPtr = (WMList *) view->self;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	WMResizeWidget(lPtr->vScroller, 1, view->size.height - 2);
 
 	updateDoubleBufferPixmap(lPtr);
