@@ -244,6 +244,10 @@ static WMData *requestHandler(WMView * view, Atom selection, Atom target, void *
 	Atom COMPOUND_TEXT = XInternAtom(dpy, "COMPOUND_TEXT", False);
 	WMData *data;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) selection;
+	(void) cdata;
+
 	count = tPtr->selection.count < 0
 	    ? tPtr->selection.position + tPtr->selection.count : tPtr->selection.position;
 
@@ -258,15 +262,14 @@ static WMData *requestHandler(WMView * view, Atom selection, Atom target, void *
 
 	_TARGETS = XInternAtom(dpy, "TARGETS", False);
 	if (target == _TARGETS) {
-		Atom *ptr;
+		Atom supported_type[4];
 
-		ptr = wmalloc(4 * sizeof(Atom));
-		ptr[0] = _TARGETS;
-		ptr[1] = XA_STRING;
-		ptr[2] = TEXT;
-		ptr[3] = COMPOUND_TEXT;
+		supported_type[0] = _TARGETS;
+		supported_type[1] = XA_STRING;
+		supported_type[2] = TEXT;
+		supported_type[3] = COMPOUND_TEXT;
 
-		data = WMCreateDataWithBytes(ptr, 4 * 4);
+		data = WMCreateDataWithBytes(supported_type, sizeof(supported_type));
 		WMSetDataFormat(data, 32);
 
 		*type = target;
@@ -281,6 +284,9 @@ static void lostSelection(WMView * view, Atom selection, void *cdata)
 {
 	TextField *tPtr = (WMTextField *) view->self;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) cdata;
+
 	if (tPtr->flags.ownsSelection) {
 		WMDeleteSelectionHandler(view, selection, CurrentTime);
 		tPtr->flags.ownsSelection = 0;
@@ -307,6 +313,9 @@ static void selectionNotification(void *observerData, WMNotification * notificat
 
 static void realizeObserver(void *self, WMNotification * not)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) not;
+
 	W_CreateIC(((TextField *) self)->view);
 }
 
@@ -482,7 +491,7 @@ void WMSetTextFieldAlignment(WMTextField * tPtr, WMAlignment alignment)
 	tPtr->flags.alignment = alignment;
 
 	if (alignment != WALeft) {
-		wwarning("only left alignment is supported in textfields");
+		wwarning(_("only left alignment is supported in textfields"));
 		return;
 	}
 
@@ -647,6 +656,9 @@ static void didResizeTextField(W_ViewDelegate * self, WMView * view)
 {
 	WMTextField *tPtr = (WMTextField *) view->self;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	tPtr->offsetWidth = WMAX((tPtr->view->size.height - WMFontHeight(tPtr->font)) / 2, 1);
 
 	tPtr->usableWidth = tPtr->view->size.width - 2 * tPtr->offsetWidth /*+ 2 */ ;
@@ -953,6 +965,7 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 	switch (ksym) {
 	case XK_Tab:
 #ifdef XK_ISO_Left_Tab
+		/* FALLTHRU */
 	case XK_ISO_Left_Tab:
 #endif
 		if (!controled) {
@@ -988,6 +1001,11 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 		}
 		break;
 
+#ifdef XK_KP_Enter
+		/* FALLTHRU */
+	case XK_KP_Enter:
+#endif
+		/* FALLTHRU */
 	case XK_Return:
 		if (!modified) {
 			data = (void *)WMReturnTextMovement;
@@ -1004,8 +1022,10 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 			controled = False;
 
 #ifdef XK_KP_Left
+		/* FALLTHRU */
 	case XK_KP_Left:
 #endif
+		/* FALLTHRU */
 	case XK_Left:
 		if (tPtr->cursorPosition > 0) {
 			int i;
@@ -1043,8 +1063,10 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 			controled = False;
 
 #ifdef XK_KP_Right
+		/* FALLTHRU */
 	case XK_KP_Right:
 #endif
+		/* FALLTHRU */
 	case XK_Right:
 		if (tPtr->cursorPosition < tPtr->textLen) {
 			int i;
@@ -1080,8 +1102,10 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 			controled = False;
 
 #ifdef XK_KP_Home
+		/* FALLTHRU */
 	case XK_KP_Home:
 #endif
+		/* FALLTHRU */
 	case XK_Home:
 		if (!controled) {
 			if (tPtr->cursorPosition > 0) {
@@ -1107,8 +1131,10 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 			controled = False;
 
 #ifdef XK_KP_End
+		/* FALLTHRU */
 	case XK_KP_End:
 #endif
+		/* FALLTHRU */
 	case XK_End:
 		if (!controled) {
 			if (tPtr->cursorPosition < tPtr->textLen) {
@@ -1134,6 +1160,7 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 		else
 			modified = False;
 
+		/* FALLTHRU */
 	case XK_BackSpace:
 		if (!modified) {
 			if (tPtr->selection.count) {
@@ -1162,8 +1189,10 @@ static void handleTextFieldKeyPress(TextField * tPtr, XEvent * event)
 			modified = False;
 
 #ifdef XK_KP_Delete
+		/* FALLTHRU */
 	case XK_KP_Delete:
 #endif
+		/* FALLTHRU */
 	case XK_Delete:
 		if (!modified) {
 			if (tPtr->selection.count) {
@@ -1304,6 +1333,12 @@ static void pasteText(WMView * view, Atom selection, Atom target, Time timestamp
 	TextField *tPtr = (TextField *) view->self;
 	char *str;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) selection;
+	(void) target;
+	(void) timestamp;
+	(void) cdata;
+
 	tPtr->flags.waitingSelection = 0;
 
 	if (data != NULL) {
