@@ -15,7 +15,7 @@ char *WMViewRealizedNotification = "WMViewRealizedNotification";
     VisibilityChangeMask|FocusChangeMask|PropertyChangeMask|\
     SubstructureNotifyMask|SubstructureRedirectMask
 
-static XSetWindowAttributes defAtts = {
+static const XSetWindowAttributes defAtts = {
 	None,			/* background_pixmap */
 	0,			/* background_pixel */
 	CopyFromParent,		/* border_pixmap */
@@ -100,7 +100,8 @@ static W_View *createView(W_Screen * screen, W_View * parent)
 		view->attribFlags = CWEventMask | CWBitGravity;
 		view->attribs = defAtts;
 
-		view->attribFlags |= CWBackPixel | CWColormap | CWBorderPixel;
+                view->attribFlags |= CWBackPixel | CWColormap | CWBorderPixel | CWBackPixmap;
+                view->attribs.background_pixmap = None;
 		view->attribs.background_pixel = W_PIXEL(screen->gray);
 		view->attribs.border_pixel = W_PIXEL(screen->black);
 		view->attribs.colormap = screen->colormap;
@@ -188,6 +189,12 @@ void W_RealizeView(W_View * view)
 	}
 
 	if (!view->flags.realized) {
+
+		if (view->parent == NULL) {
+			wwarning("trying to realize widget without parent");
+			return;
+		}
+
 		parentWID = view->parent->window;
 		view->window = XCreateWindow(dpy, parentWID, view->pos.x, view->pos.y,
 					     view->size.width, view->size.height, 0,
@@ -483,6 +490,7 @@ void W_SetViewBackgroundColor(W_View * view, WMColor * color)
 	view->backColor = WMRetainColor(color);
 
 	view->attribFlags |= CWBackPixel;
+	view->attribFlags &= ~CWBackPixmap;
 	view->attribs.background_pixel = W_PIXEL(color);
 	if (view->flags.realized) {
 		XSetWindowBackground(view->screen->display, view->window, W_PIXEL(color));
@@ -490,6 +498,21 @@ void W_SetViewBackgroundColor(W_View * view, WMColor * color)
 	}
 }
 
+void W_SetViewBackgroundPixmap(W_View *view, WMPixmap *pix)
+{
+       if (view->backImage)
+               WMReleasePixmap(view->backImage);
+       view->backImage = WMRetainPixmap(pix);
+
+       view->attribFlags |= CWBackPixmap;
+       view->attribFlags &= ~CWBackPixel;
+       view->attribs.background_pixmap = pix->pixmap;
+       if (view->flags.realized) {
+               XSetWindowBackgroundPixmap(view->screen->display, view->window, pix->pixmap);
+               XClearWindow(view->screen->display, view->window);
+       }
+}
+
 void W_SetViewCursor(W_View * view, Cursor cursor)
 {
 	view->cursor = cursor;
