@@ -1,8 +1,12 @@
 
 #include <X11/Xmd.h>
 
+#include "wconfig.h"
+
 #include "WINGsP.h"
 
+#include "GNUstep.h"
+
 #include <X11/Xatom.h>
 
 typedef struct W_Window {
@@ -46,32 +50,6 @@ typedef struct W_Window {
 	} flags;
 } _Window;
 
-typedef struct {
-	CARD32 flags;
-	CARD32 window_style;
-	CARD32 window_level;
-	CARD32 reserved;
-	Pixmap miniaturize_pixmap;	/* pixmap for miniaturize button */
-	Pixmap close_pixmap;	/* pixmap for close button */
-	Pixmap miniaturize_mask;	/* miniaturize pixmap mask */
-	Pixmap close_mask;	/* close pixmap mask */
-	CARD32 extra_flags;
-} GNUstepWMAttributes;
-
-#define GSWindowStyleAttr 	(1<<0)
-#define GSWindowLevelAttr 	(1<<1)
-#define GSMiniaturizePixmapAttr	(1<<3)
-#define GSClosePixmapAttr	(1<<4)
-#define GSMiniaturizeMaskAttr	(1<<5)
-#define GSCloseMaskAttr		(1<<6)
-#define GSExtraFlagsAttr	(1<<7)
-
-/* extra flags */
-#define GSDocumentEditedFlag	(1<<0)
-#define GSNoApplicationIconFlag	(1<<5)
-
-#define WMFHideOtherApplications	10
-#define WMFHideApplication		12
 
 static void willResizeWindow(W_ViewDelegate *, WMView *, unsigned *, unsigned *);
 
@@ -85,7 +63,6 @@ struct W_ViewDelegate _WindowViewDelegate = {
 
 #define DEFAULT_WIDTH	400
 #define DEFAULT_HEIGHT	180
-#define DEFAULT_TITLE	""
 
 static void destroyWindow(_Window * win);
 
@@ -95,6 +72,9 @@ static void realizeWindow(WMWindow * win);
 
 static void realizeObserver(void *self, WMNotification * not)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) not;
+
 	realizeWindow(self);
 }
 
@@ -177,7 +157,7 @@ static void setWindowTitle(WMWindow * win, const char *title)
 
 	result = XmbTextListToTextProperty(scr->display, (char **)&title, 1, XStdICCTextStyle, &property);
 	if (result == XNoMemory || result == XLocaleNotSupported) {
-		wwarning("window title conversion error... using STRING encoding");
+		wwarning(_("window title conversion error... using STRING encoding"));
 		XStoreName(scr->display, win->view->window, title);
 	} else {
 		XSetWMName(scr->display, win->view->window, &property);
@@ -198,7 +178,7 @@ static void setMiniwindowTitle(WMWindow * win, const char *title)
 
 	result = XmbTextListToTextProperty(scr->display, (char **)&title, 1, XStdICCTextStyle, &property);
 	if (result == XNoMemory || result == XLocaleNotSupported) {
-		wwarning("icon title conversion error..using STRING encoding");
+		wwarning(_("icon title conversion error... using STRING encoding"));
 		XSetIconName(scr->display, win->view->window, title);
 	} else {
 		XSetWMIconName(scr->display, win->view->window, &property);
@@ -214,7 +194,7 @@ static void setMiniwindowTitle(WMWindow * win, const char *title)
 static void setMiniwindow(WMWindow *win, RImage *image)
 {
 	WMScreen *scr = win->view->screen;
-	long *data;
+	unsigned long *data;
 	int x, y;
 	int o;
 
@@ -229,15 +209,19 @@ static void setMiniwindow(WMWindow *win, RImage *image)
 
 	for (y = 0; y < image->height; y++) {
 		for (x = 0; x < image->width; x++) {
-			long pixel;
+			unsigned long pixel;
 			int offs = (x + y * image->width);
 
-			if (image->format == RRGBFormat)
-				pixel = image->data[offs * 3] << 16 | image->data[offs * 3 + 1] << 8
-				        | image->data[offs * 3 + 2];
-			else
-				pixel = image->data[offs * 4] << 16 | image->data[offs * 4 + 1] << 8
-				        | image->data[offs * 4 + 2] | image->data[offs * 4 + 3] << 24;
+			if (image->format == RRGBFormat) {
+				pixel  = ((unsigned long) image->data[offs * 3    ]) << 16;
+				pixel |= ((unsigned long) image->data[offs * 3 + 1]) <<  8;
+				pixel |= ((unsigned long) image->data[offs * 3 + 2]);
+			} else {
+				pixel  = ((unsigned long) image->data[offs * 4    ]) << 16;
+				pixel |= ((unsigned long) image->data[offs * 4 + 1]) <<  8;
+				pixel |= ((unsigned long) image->data[offs * 4 + 2]);
+				pixel |= ((unsigned long) image->data[offs * 4 + 3]) << 24;
+			}
 
 			data[o++] = pixel;
 		}
@@ -252,12 +236,12 @@ static void setMiniwindow(WMWindow *win, RImage *image)
 
 void WMSetWindowTitle(WMWindow * win, const char *title)
 {
+	wassertr(title != NULL);
+
 	if (win->title != NULL)
 		wfree(win->title);
-	if (title != NULL)
-		win->title = wstrdup(title);
-	else
-		win->title = NULL;
+
+	win->title = wstrdup(title);
 
 	if (win->view->flags.realized) {
 		setWindowTitle(win, title);
@@ -311,6 +295,9 @@ static void willResizeWindow(W_ViewDelegate * self, WMView * view, unsigned *wid
 {
 	WMWindow *win = (WMWindow *) view->self;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	if (win->minSize.width > 0 && win->minSize.height > 0) {
 		if (*width < win->minSize.width)
 			*width = win->minSize.width;
@@ -600,8 +587,8 @@ void WMSetWindowMiniwindowPixmap(WMWindow * win, WMPixmap * pixmap)
 
 void WMSetWindowMiniwindowTitle(WMWindow * win, const char *title)
 {
-	if ((win->miniTitle && !title) || (!win->miniTitle && title)
-	    || (title && win->miniTitle && strcoll(title, win->miniTitle) != 0)) {
+	if (win && ((win->miniTitle && !title) || (!win->miniTitle && title)
+	    || (title && win->miniTitle && strcoll(title, win->miniTitle) != 0))) {
 		if (win->miniTitle)
 			wfree(win->miniTitle);
 
