@@ -138,6 +138,7 @@ static void storeData(_Panel * panel)
 	if (sscanf(str, "%i", &i) != 1)
 		i = 0;
 	SetIntegerForKey(i, "RaiseDelay");
+	free(str);
 
 	SetBoolForKey(WMGetButtonSelected(panel->ignB), "IgnoreFocusClick");
 	SetBoolForKey(WMGetButtonSelected(panel->newB), "AutoFocus");
@@ -150,7 +151,7 @@ static void pushDelayButton(WMWidget * w, void *data)
 
 	panel->raiseDelaySelected = 1;
 	if (w == panel->raisB[0]) {
-		WMSetTextFieldText(panel->raisT, "OFF");
+		WMSetTextFieldText(panel->raisT, _("OFF"));
 	} else if (w == panel->raisB[1]) {
 		WMSetTextFieldText(panel->raisT, "10");
 	} else if (w == panel->raisB[2]) {
@@ -167,6 +168,9 @@ static void raiseTextChanged(void *observerData, WMNotification * notification)
 	_Panel *panel = (_Panel *) observerData;
 	int i;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) notification;
+
 	if (panel->raiseDelaySelected) {
 		for (i = 0; i < 5; i++) {
 			WMSetButtonSelected(panel->raisB[i], False);
@@ -201,13 +205,13 @@ static void createPanel(Panel * p)
 
 		panel->kfocB[0] = WMCreateRadioButton(box);
 		WMSetButtonText(panel->kfocB[0], _("Manual:  Click on the window to set "
-						   "keyboard input focus."));
+		                                   "keyboard input focus"));
 		WMAddBoxSubview(box, WMWidgetView(panel->kfocB[0]), True, True, 20, 0, 0);
 
 		panel->kfocB[1] = WMCreateRadioButton(box);
 		WMGroupButtons(panel->kfocB[0], panel->kfocB[1]);
 		WMSetButtonText(panel->kfocB[1], _("Auto:  Set keyboard input focus to "
-						   "the window under the mouse pointer."));
+		                                   "the window under the mouse pointer"));
 		WMAddBoxSubview(box, WMWidgetView(panel->kfocB[1]), True, True, 20, 0, 0);
 
 		WMMapSubwidgets(box);
@@ -219,17 +223,26 @@ static void createPanel(Panel * p)
 	panel->cfocF = WMCreateFrame(panel->box);
 	WMResizeWidget(panel->cfocF, 240, 77);
 	WMMoveWidget(panel->cfocF, 15, 143);
-	WMSetFrameTitle(panel->cfocF, _("Install colormap in the window..."));
+	WMSetFrameTitle(panel->cfocF, _("Install colormap from the window..."));
+
+	WMSetBalloonTextForView(_("This option is for screens that can display only a limited number\n"
+	                          "of colors at a time, so they use an indexed table of colors (called\n"
+	                          "a ColorMap) that each application customizes for its needs, and\n"
+	                          "WindowMaker will set the global ColorMap dynamically from the\n"
+	                          "active application.\n"
+	                          "You can know the capability of your screen in WindowMaker's info\n"
+	                          "panel as the 'visual'."),
+	                        WMWidgetView(panel->cfocF));
 
 	panel->manB = WMCreateRadioButton(panel->cfocF);
-	WMResizeWidget(panel->manB, 225, 20);
-	WMMoveWidget(panel->manB, 10, 20);
-	WMSetButtonText(panel->manB, _("...that has the input focus."));
+	WMResizeWidget(panel->manB, 226, 24);
+	WMMoveWidget(panel->manB, 9, 18);
+	WMSetButtonText(panel->manB, _("...that has the input focus"));
 
 	panel->autB = WMCreateRadioButton(panel->cfocF);
-	WMResizeWidget(panel->autB, 225, 20);
-	WMMoveWidget(panel->autB, 10, 45);
-	WMSetButtonText(panel->autB, _("...that's under the mouse pointer."));
+	WMResizeWidget(panel->autB, 226, 24);
+	WMMoveWidget(panel->autB, 9, 43);
+	WMSetButtonText(panel->autB, _("...that's under the mouse pointer"));
 	WMGroupButtons(panel->manB, panel->autB);
 
 	WMMapSubwidgets(panel->cfocF);
@@ -293,7 +306,7 @@ static void createPanel(Panel * p)
 	panel->raisL = WMCreateLabel(panel->raisF);
 	WMResizeWidget(panel->raisL, 36, 16);
 	WMMoveWidget(panel->raisL, 205, 32);
-	WMSetLabelText(panel->raisL, _("msec"));
+	WMSetLabelText(panel->raisL, _("ms"));
 	WMSetLabelTextColor(panel->raisL, color);
 	WMSetLabelFont(panel->raisL, font);
 
@@ -308,19 +321,19 @@ static void createPanel(Panel * p)
 	WMMoveWidget(panel->optF, 265, 88);
 
 	panel->ignB = WMCreateSwitchButton(panel->optF);
-	WMResizeWidget(panel->ignB, 225, 50);
+	WMResizeWidget(panel->ignB, 228, 50-2);
 	WMMoveWidget(panel->ignB, 10, 4);
-	WMSetButtonText(panel->ignB, _("Do not let applications receive " "the click used to focus windows."));
+	WMSetButtonText(panel->ignB, _("Do not let applications receive the click used to focus windows"));
 
 	panel->newB = WMCreateSwitchButton(panel->optF);
-	WMResizeWidget(panel->newB, 225, 35);
-	WMMoveWidget(panel->newB, 10, 49);
-	WMSetButtonText(panel->newB, _("Automatically focus new windows."));
+	WMResizeWidget(panel->newB, 228, 35);
+	WMMoveWidget(panel->newB, 10, 52);
+	WMSetButtonText(panel->newB, _("Automatically focus new windows"));
 
 	panel->craisB = WMCreateSwitchButton(panel->optF);
-	WMResizeWidget(panel->craisB, 225, 36);
-	WMMoveWidget(panel->craisB, 10, 85);
-	WMSetButtonText(panel->craisB, _("Raise window when switching\nfocus with keyboard."));
+	WMResizeWidget(panel->craisB, 228, 36);
+	WMMoveWidget(panel->craisB, 10, 87);
+	WMSetButtonText(panel->craisB, _("Raise window when switching focus with keyboard"));
 
 	WMMapSubwidgets(panel->optF);
 
@@ -330,7 +343,7 @@ static void createPanel(Panel * p)
 	showData(panel);
 }
 
-Panel *InitFocus(WMScreen *scr, WMWidget *parent)
+Panel *InitFocus(WMWidget *parent)
 {
 	_Panel *panel;
 
