@@ -89,6 +89,8 @@ static const struct {
 	{ "LBCMaximizeKey", N_("Maximize active window left bottom corner") },
 	{ "RBCMaximizeKey", N_("Maximize active window right bottom corner") },
 	{ "MaximusKey",     N_("Maximus: Tiled maximization ") },
+	{ "KeepOnTopKey",   N_("Toggle window on top status") },
+	{ "KeepAtBottomKey",N_("Toggle window at bottom status") },
 	{ "OmnipresentKey", N_("Toggle window omnipresent status") },
 	{ "RaiseKey",       N_("Raise active window") },
 	{ "LowerKey",       N_("Lower active window") },
@@ -146,6 +148,10 @@ static const struct {
 	{ "WindowShortcut9Key",  N_("Shortcut for window 9") },
 	{ "WindowShortcut10Key", N_("Shortcut for window 10") },
 
+	/* Head Selection */
+	{ "MoveTo12to6Head",     N_("Move to right/bottom/left/top head") },
+	{ "MoveTo6to12Head",    N_("Move to left/top/right/bottom head") },
+
 	/* Misc. */
 	{ "WindowRelaunchKey", N_("Launch new instance of application") },
 	{ "ScreenSwitchKey",   N_("Switch to Next Screen/Monitor") },
