@@ -19,12 +19,15 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
+
 #include "WPrefs.h"
 #include <assert.h>
 
+#ifdef HAVE_STDNORETURN
+#include <stdnoreturn.h>
+#endif
 
-#define ICON_TITLE_FONT "sans serif:pixelsize=9"
-#define ICON_TITLE_VFONT "sans serif:pixelsize=9:weight=100"
 
 #define MAX_SECTIONS 16
 
@@ -70,10 +73,15 @@ static void savePanelData(Panel * panel);
 
 static void prepareForClose(void);
 
-static void quit(WMWidget *w, void *data)
+static noreturn void quit(WMWidget *w, void *data)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) w;
+	(void) data;
+
 	prepareForClose();
 
+	WMReleaseApplication();
 	exit(0);
 }
 
@@ -85,6 +93,9 @@ static void save(WMWidget * w, void *data)
 	WMPropList *key;
 	XEvent ev;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) data;
+
 	/*    puts("gathering data"); */
 	for (i = 0; i < WPrefs.sectionCount; i++) {
 		PanelRec *rec = WMGetHangedData(WPrefs.sectionB[i]);
@@ -134,6 +145,10 @@ static void undo(WMWidget * w, void *data)
 {
 	PanelRec *rec = (PanelRec *) WPrefs.currentPanel;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) w;
+	(void) data;
+
 	if (!rec)
 		return;
 
@@ -146,6 +161,10 @@ static void undoAll(WMWidget * w, void *data)
 {
 	int i;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) w;
+	(void) data;
+
 	for (i = 0; i < WPrefs.sectionCount; i++) {
 		PanelRec *rec = WMGetHangedData(WPrefs.sectionB[i]);
 
@@ -171,6 +190,10 @@ static void toggleBalloons(WMWidget *w, void *data)
 	WMUserDefaults *udb = WMGetStandardUserDefaults();
 	Bool flag;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) w;
+	(void) data;
+
 	flag = WMGetButtonSelected(WPrefs.balloonBtn);
 
 	WMSetBalloonEnabled(WMWidgetScreen(WPrefs.win), flag);
@@ -190,7 +213,7 @@ static void createMainWindow(WMScreen * scr)
 	WMSetWindowCloseAction(WPrefs.win, quit, NULL);
 	WMSetWindowMaxSize(WPrefs.win, 520, 390);
 	WMSetWindowMinSize(WPrefs.win, 520, 390);
-	WMSetWindowMiniwindowTitle(WPrefs.win, "Preferences");
+	WMSetWindowMiniwindowTitle(WPrefs.win, _("Preferences"));
 
 	WPrefs.scrollV = WMCreateScrollView(WPrefs.win);
 	WMResizeWidget(WPrefs.scrollV, 500, 87);
@@ -317,6 +340,9 @@ static void savePanelData(Panel * panel)
 
 static void changeSection(WMWidget * self, void *data)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	if (WPrefs.currentPanel == data)
 		return;
 
@@ -415,77 +441,9 @@ void CreateImages(WMScreen *scr, RContext *rc, RImage *xis, const char *file,
 }
 
 
-static WMPixmap *makeTitledIcon(WMScreen * scr, WMPixmap * icon, const char *title1, const char *title2)
-{
-	return WMRetainPixmap(icon);
-
-#if 0
-	static GC gc = NULL;
-	static XFontStruct *hfont = NULL;
-	static XFontStruct *vfont = NULL;
-	WMPixmap *tmp;
-	Pixmap pix, mask;
-	Display *dpy = WMScreenDisplay(scr);
-	WMColor *black = WMBlackColor(scr);
-	GC fgc;
-	WMSize size = WMGetPixmapSize(icon);
-
-	tmp = WMCreatePixmap(scr, 60, 60, WMScreenDepth(scr), True);
-
-	pix = WMGetPixmapXID(tmp);
-	mask = WMGetPixmapMaskXID(tmp);
-
-	if (gc == NULL) {
-		gc = XCreateGC(dpy, mask, 0, NULL);
-
-		hfont = XLoadQueryFont(dpy, ICON_TITLE_FONT);
-		vfont = XLoadQueryFont(dpy, ICON_TITLE_VFONT);
-	}
-
-	if (hfont == NULL) {
-		return WMRetainPixmap(icon);
-	}
-
-	XSetForeground(dpy, gc, 0);
-	XFillRectangle(dpy, mask, gc, 0, 0, 60, 60);
-
-	fgc = WMColorGC(black);
-
-	XSetForeground(dpy, gc, 1);
-
-	XCopyArea(dpy, WMGetPixmapXID(icon), pix, fgc, 0, 0, size.width, size.height, 12, 12);
-
-	if (WMGetPixmapMaskXID(icon) != None)
-		XCopyPlane(dpy, WMGetPixmapMaskXID(icon), mask, gc, 0, 0, size.width, size.height, 12, 12, 1);
-	else
-		XFillRectangle(dpy, mask, gc, 12, 12, 48, 48);
-
-	if (title1) {
-		XSetFont(dpy, fgc, vfont->fid);
-		XSetFont(dpy, gc, vfont->fid);
-
-		XDrawString(dpy, pix, fgc, 0, vfont->ascent, title1, strlen(title1));
-
-		XDrawString(dpy, mask, gc, 0, vfont->ascent, title1, strlen(title1));
-	}
-
-	if (title2) {
-		XSetFont(dpy, fgc, hfont->fid);
-		XSetFont(dpy, gc, hfont->fid);
-
-		XDrawString(dpy, pix, fgc, (title1 ? 12 : 0), hfont->ascent, title2, strlen(title2));
-
-		XDrawString(dpy, mask, gc, (title1 ? 12 : 0), hfont->ascent, title2, strlen(title2));
-	}
-
-	return tmp;
-#endif
-}
-
-void SetButtonAlphaImage(WMScreen * scr, WMButton * bPtr, const char *file, const char *title1, const char *title2)
+void SetButtonAlphaImage(WMScreen *scr, WMButton *bPtr, const char *file)
 {
 	WMPixmap *icon;
-	WMPixmap *icon2;
 	RColor color;
 	char *iconPath;
 
@@ -503,18 +461,7 @@ void SetButtonAlphaImage(WMScreen * scr, WMButton * bPtr, const char *file, cons
 		icon = NULL;
 	}
 
-	if (icon) {
-		icon2 = makeTitledIcon(scr, icon, title1, title2);
-		if (icon)
-			WMReleasePixmap(icon);
-	} else {
-		icon2 = NULL;
-	}
-
-	WMSetButtonImage(bPtr, icon2);
-
-	if (icon2)
-		WMReleasePixmap(icon2);
+	WMSetButtonImage(bPtr, icon);
 
 	color.red = 0xff;
 	color.green = 0xff;
@@ -551,26 +498,13 @@ void AddSection(Panel * panel, const char *iconFile)
 	WMHangData(bPtr, panel);
 
 	WMSetBalloonTextForView(((PanelRec *) panel)->description, WMWidgetView(bPtr));
-
-	{
-		char *t1, *t2;
-
-		t1 = wstrdup(((PanelRec *) panel)->sectionName);
-		t2 = strchr(t1, ' ');
-		if (t2) {
-			*t2 = 0;
-			t2++;
-		}
-		SetButtonAlphaImage(WMWidgetScreen(bPtr), bPtr, iconFile, t1, t2);
-		wfree(t1);
-	}
+	SetButtonAlphaImage(WMWidgetScreen(bPtr), bPtr, iconFile);
 	WMMapWidget(bPtr);
 
 	WPrefs.sectionB[WPrefs.sectionCount] = bPtr;
 
-	if (WPrefs.sectionCount > 0) {
+	if (WPrefs.sectionCount > 0)
 		WMGroupButtons(WPrefs.sectionB[0], bPtr);
-	}
 
 	WPrefs.sectionCount++;
 
@@ -623,41 +557,41 @@ void Initialize(WMScreen * scr)
 
 	WMSetLabelText(WPrefs.statusL, _("Initializing configuration panels..."));
 
-	InitFocus(scr, WPrefs.banner);
-	InitWindowHandling(scr, WPrefs.banner);
+	InitFocus(WPrefs.banner);
+	InitWindowHandling(WPrefs.banner);
 
-	InitMenuPreferences(scr, WPrefs.banner);
-	InitIcons(scr, WPrefs.banner);
-	InitPreferences(scr, WPrefs.banner);
+	InitMenuPreferences(WPrefs.banner);
+	InitIcons(WPrefs.banner);
+	InitPreferences(WPrefs.banner);
 
-	InitPaths(scr, WPrefs.banner);
-	InitDocks(scr, WPrefs.banner);
-	InitWorkspace(scr, WPrefs.banner);
-	InitConfigurations(scr, WPrefs.banner);
+	InitPaths(WPrefs.banner);
+	InitDocks(WPrefs.banner);
+	InitWorkspace(WPrefs.banner);
+	InitConfigurations(WPrefs.banner);
 
-	InitMenu(scr, WPrefs.banner);
+	InitMenu(WPrefs.banner);
 
 #ifdef not_yet_fully_implemented
-	InitKeyboardSettings(scr, WPrefs.banner);
+	InitKeyboardSettings(WPrefs.banner);
 #endif
-	InitKeyboardShortcuts(scr, WPrefs.banner);
-	InitMouseSettings(scr, WPrefs.banner);
+	InitKeyboardShortcuts(WPrefs.banner);
+	InitMouseSettings(WPrefs.banner);
 
-	InitAppearance(scr, WPrefs.banner);
+	InitAppearance(WPrefs.banner);
 
-	InitFontSimple(scr, WPrefs.banner);
+	InitFontSimple(WPrefs.banner);
 
 #ifdef not_yet_fully_implemented
-	InitThemes(scr, WPrefs.banner);
+	InitThemes(WPrefs.banner);
 #endif
-	InitExpert(scr, WPrefs.banner);
+	InitExpert(WPrefs.banner);
 
 	WMRealizeWidget(WPrefs.scrollV);
 
 	WMSetLabelText(WPrefs.statusL, "");
 }
 
-WMWindow *GetWindow(Panel * panel)
+WMWindow *GetWindow(void)
 {
 	return WPrefs.win;
 }
@@ -668,7 +602,7 @@ static void loadConfigurations(WMScreen * scr, WMWindow * mainw)
 	char *path;
 	FILE *file;
 	char buffer[1024];
-	char mbuf[1024];
+	char mbuf[1069]; /* Size of buffer and extra characters for the sprintfs */
 	int v1, v2, v3;
 
 	path = wdefaultspathfordomain("WindowMaker");
@@ -915,7 +849,7 @@ void SetIntegerForKey(int value, const char *defaultName)
 	WMReleasePropList(object);
 }
 
-void SetStringForKey(const char *value, const const char *defaultName)
+void SetStringForKey(const char *value, const char *defaultName)
 {
 	WMPropList *object;
 
