@@ -86,13 +86,13 @@ void wDockReattachIcon(WDock *dock, WAppIcon *icon, int x, int y);
 void wSlideAppicons(WAppIcon **appicons, int n, int to_the_left);
 void wDrawerFillTheGap(WDock *drawer, WAppIcon *aicon, Bool redocking);
 
-void wDockFinishLaunch(WDock *dock, WAppIcon *icon);
+void wDockFinishLaunch(WAppIcon *icon);
 void wDockTrackWindowLaunch(WDock *dock, Window window);
 WAppIcon *wDockFindIconForWindow(WDock *dock, Window window);
 void wDockDoAutoLaunch(WDock *dock, int workspace);
-void wDockLaunchWithState(WDock *dock, WAppIcon *btn, WSavedState *state);
+void wDockLaunchWithState(WAppIcon *btn, WSavedState *state);
 
-#ifdef XDND
+#ifdef USE_DOCK_XDND
 int wDockReceiveDNDDrop(WScreen *scr, XEvent *event);
 #endif
 
@@ -104,11 +104,11 @@ WAppIcon *wClipRestoreState(WScreen *scr, WMPropList *clip_state);
 void wDrawerIconPaint(WAppIcon *dicon);
 void wDrawersSaveState(WScreen *scr);
 void wDrawersRestoreState(WScreen *scr);
-int wIsADrawer(WScreen *scr, WAppIcon *aicon);
+int wIsADrawer(WAppIcon *aicon);
 
 void wClipUpdateForWorkspaceChange(WScreen *scr, int workspace);
 
-RImage *wClipMakeTile(WScreen *scr, RImage *normalTile);
+RImage *wClipMakeTile(RImage *normalTile);
 RImage* wDrawerMakeTile(WScreen *scr, RImage *normalTile);
 
 #define WO_FAILED          0
