@@ -132,6 +132,10 @@ enum {
 	WKBD_WINDOW9,
 	WKBD_WINDOW10,
 
+	/* shortcuts to move window between heads */
+	WKBD_MOVE_12_TO_6_HEAD,
+	WKBD_MOVE_6_TO_12_HEAD,
+
 	/* launch a new instance of the active window */
 	WKBD_RELAUNCH,
 
