@@ -35,12 +35,9 @@
 #include "misc.h"
 #include "xinerama.h"
 
-extern Atom _XA_WM_IGNORE_FOCUS_EVENTS;
 
-#ifdef SHAPE
+#ifdef USE_XSHAPE
 #include <X11/extensions/shape.h>
-
-extern Bool wShapeSupported;
 #endif
 
 struct SwitchPanel {
@@ -66,12 +63,15 @@ struct SwitchPanel {
 	WMColor *white;
 };
 
-#define BORDER_SPACE 10
-#define ICON_SIZE 48
-#define ICON_TILE_SIZE 64
-#define LABEL_HEIGHT 25
+/* these values will be updated whenever the switch panel
+ * is created to to match the size defined in switch_panel_icon_size
+ * and the selected font size */
+static short int icon_size;
+static short int border_space;
+static short int icon_tile_size;
+static short int label_height;
+
 #define SCREEN_BORDER_SPACING 2*20
-#define SCROLL_STEPS (ICON_TILE_SIZE/2)
 
 #define ICON_SELECTED (1<<1)
 #define ICON_DIM (1<<2)
@@ -112,8 +112,8 @@ static void changeImage(WSwitchPanel *panel, int idecks, int selected, Bool dim,
 {
 	WMFrame *icon = NULL;
 	RImage *image = NULL;
-	char flags = 0;
-	char desired = 0;
+	int flags;
+	int desired = 0;
 
 	/* This whole function is a no-op if we aren't drawing the panel */
 	if (!wPreferences.swtileImage)
@@ -121,7 +121,7 @@ static void changeImage(WSwitchPanel *panel, int idecks, int selected, Bool dim,
 
 	icon = WMGetFromArray(panel->icons, idecks);
 	image = WMGetFromArray(panel->images, idecks);
-	flags = (char) (uintptr_t) WMGetFromArray(panel->flags, idecks);
+	flags = (int) (uintptr_t) WMGetFromArray(panel->flags, idecks);
 
 	if (selected)
 		desired |= ICON_SELECTED;
@@ -150,8 +150,8 @@ static void changeImage(WSwitchPanel *panel, int idecks, int selected, Bool dim,
 		back = panel->tileTmp;
 		if (panel->bg) {
 			RCopyArea(back, panel->bg,
-				  BORDER_SPACE + pos.x - panel->firstVisible * ICON_TILE_SIZE,
-				  BORDER_SPACE + pos.y, back->width, back->height, 0, 0);
+				  border_space + pos.x - panel->firstVisible * icon_tile_size,
+				  border_space + pos.y, back->width, back->height, 0, 0);
 		} else {
 			RColor color;
 			WMScreen *wscr = WMWidgetScreen(icon);
@@ -188,7 +188,7 @@ static void addIconForWindow(WSwitchPanel *panel, WMWidget *parent, WWindow *wwi
 	RImage *image = NULL;
 
 	WMSetFrameRelief(icon, WRFlat);
-	WMResizeWidget(icon, ICON_TILE_SIZE, ICON_TILE_SIZE);
+	WMResizeWidget(icon, icon_tile_size, icon_tile_size);
 	WMMoveWidget(icon, x, y);
 
 	if (!WFLAGP(wwin, always_user_icon) && wwin->net_icon_image)
@@ -196,10 +196,10 @@ static void addIconForWindow(WSwitchPanel *panel, WMWidget *parent, WWindow *wwi
 
 	/* get_icon_image() includes the default icon image */
 	if (!image)
-		image = get_icon_image(panel->scr, wwin->wm_instance, wwin->wm_class, ICON_TILE_SIZE);
+		image = get_icon_image(panel->scr, wwin->wm_instance, wwin->wm_class, icon_tile_size);
 
-	/* We must resize the icon size (~64) to the switchpanel icon size (~48) */
-	image = wIconValidateIconSize(image, ICON_SIZE);
+	/* We must resize the icon size (~64) to the switch panel icon size (~48) */
+	image = wIconValidateIconSize(image, icon_size);
 
 	WMAddToArray(panel->images, image);
 	WMAddToArray(panel->icons, icon);
@@ -223,14 +223,14 @@ static void scrollIcons(WSwitchPanel *panel, int delta)
 	if (nfirst == panel->firstVisible)
 		return;
 
-	WMMoveWidget(panel->iconBox, -nfirst * ICON_TILE_SIZE, 0);
+	WMMoveWidget(panel->iconBox, -nfirst * icon_tile_size, 0);
 
 	panel->firstVisible = nfirst;
 
 	for (i = panel->firstVisible; i < panel->firstVisible + panel->visibleCount; i++) {
 		if (i == panel->current)
 			continue;
-		dim = ((char) (uintptr_t) WMGetFromArray(panel->flags, i) & ICON_DIM);
+		dim = ((int) (uintptr_t) WMGetFromArray(panel->flags, i) & ICON_DIM);
 		changeImage(panel, i, 0, dim, True);
 	}
 }
@@ -242,19 +242,10 @@ static void scrollIcons(WSwitchPanel *panel, int delta)
  */
 static RImage *assemblePuzzleImage(RImage **images, int width, int height)
 {
-	RImage *img = RCreateImage(width, height, 1);
+	RImage *img;
 	RImage *tmp;
 	int tw, th;
 	RColor color;
-	if (!img)
-		return NULL;
-
-	color.red = 0;
-	color.green = 0;
-	color.blue = 0;
-	color.alpha = 255;
-
-	RFillImage(img, &color);
 
 	tw = width - images[0]->width - images[2]->width;
 	th = height - images[0]->height - images[6]->height;
@@ -262,36 +253,40 @@ static RImage *assemblePuzzleImage(RImage **images, int width, int height)
 	if (tw <= 0 || th <= 0)
 		return NULL;
 
+	img = RCreateImage(width, height, 1);
+	if (!img)
+		return NULL;
+
+	color.red   =   0;
+	color.green =   0;
+	color.blue  =   0;
+	color.alpha = 255;
+	RFillImage(img, &color);
+
 	/* top */
-	if (tw > 0) {
-		tmp = RSmoothScaleImage(images[1], tw, images[1]->height);
-		RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[0]->width, 0);
-		RReleaseImage(tmp);
-	}
+	tmp = RSmoothScaleImage(images[1], tw, images[1]->height);
+	RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[0]->width, 0);
+	RReleaseImage(tmp);
+
 	/* bottom */
-	if (tw > 0) {
-		tmp = RSmoothScaleImage(images[7], tw, images[7]->height);
-		RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[6]->width, height - images[6]->height);
-		RReleaseImage(tmp);
-	}
+	tmp = RSmoothScaleImage(images[7], tw, images[7]->height);
+	RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[6]->width, height - images[6]->height);
+	RReleaseImage(tmp);
+
 	/* left */
-	if (th > 0) {
-		tmp = RSmoothScaleImage(images[3], images[3]->width, th);
-		RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, 0, images[0]->height);
-		RReleaseImage(tmp);
-	}
+	tmp = RSmoothScaleImage(images[3], images[3]->width, th);
+	RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, 0, images[0]->height);
+	RReleaseImage(tmp);
+
 	/* right */
-	if (th > 0) {
-		tmp = RSmoothScaleImage(images[5], images[5]->width, th);
-		RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, width - images[5]->width, images[2]->height);
-		RReleaseImage(tmp);
-	}
+	tmp = RSmoothScaleImage(images[5], images[5]->width, th);
+	RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, width - images[5]->width, images[2]->height);
+	RReleaseImage(tmp);
+
 	/* center */
-	if (tw > 0 && th > 0) {
-		tmp = RSmoothScaleImage(images[4], tw, th);
-		RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[0]->width, images[0]->height);
-		RReleaseImage(tmp);
-	}
+	tmp = RSmoothScaleImage(images[4], tw, th);
+	RCopyArea(img, tmp, 0, 0, tmp->width, tmp->height, images[0]->width, images[0]->height);
+	RReleaseImage(tmp);
 
 	/* corners */
 	RCopyArea(img, images[0], 0, 0, images[0]->width, images[0]->height, 0, 0);
@@ -315,7 +310,7 @@ static RImage *getTile(void)
 	if (!wPreferences.swtileImage)
 		return NULL;
 
-	stile = RScaleImage(wPreferences.swtileImage, ICON_TILE_SIZE, ICON_TILE_SIZE);
+	stile = RScaleImage(wPreferences.swtileImage, icon_tile_size, icon_tile_size);
 	if (!stile)
 		return wPreferences.swtileImage;
 
@@ -329,23 +324,23 @@ static void drawTitle(WSwitchPanel *panel, int idecks, const char *title)
 	int x;
 
 	if (title)
-		ntitle = ShrinkString(panel->font, title, width - 2 * BORDER_SPACE);
+		ntitle = ShrinkString(panel->font, title, width - 2 * border_space);
 	else
 		ntitle = NULL;
 
 	if (panel->bg) {
 		if (ntitle) {
 			if (strcmp(ntitle, title) != 0) {
-				x = BORDER_SPACE;
+				x = border_space;
 			} else {
 				int w = WMWidthOfString(panel->font, ntitle, strlen(ntitle));
 
-				x = BORDER_SPACE + (idecks - panel->firstVisible) * ICON_TILE_SIZE +
-				    ICON_TILE_SIZE / 2 - w / 2;
-				if (x < BORDER_SPACE)
-					x = BORDER_SPACE;
-				else if (x + w > width - BORDER_SPACE)
-					x = width - BORDER_SPACE - w;
+				x = border_space + (idecks - panel->firstVisible) * icon_tile_size+
+				    icon_tile_size/ 2 - w / 2;
+				if (x < border_space)
+					x = border_space;
+				else if (x + w > width - border_space)
+					x = width - border_space - w;
 			}
 		}
 
@@ -355,7 +350,7 @@ static void drawTitle(WSwitchPanel *panel, int idecks, const char *title)
 				     WMWidgetXID(panel->win),
 				     panel->white, panel->font,
 				     x,
-				     WMWidgetHeight(panel->win) - BORDER_SPACE - LABEL_HEIGHT +
+				     WMWidgetHeight(panel->win) - border_space - label_height +
 				     WMFontHeight(panel->font) / 2, ntitle, strlen(ntitle));
 	} else {
 		if (ntitle)
@@ -366,57 +361,48 @@ static void drawTitle(WSwitchPanel *panel, int idecks, const char *title)
 		free(ntitle);
 }
 
-static WMArray *makeWindowListArray(WWindow *curwin, int include_unmapped, Bool class_only)
+static WMArray *makeWindowListArray(WScreen *scr, int include_unmapped, Bool class_only)
 {
 	WMArray *windows = WMCreateArray(10);
-	int fl;
-	WWindow *wwin;
+	WWindow *wwin = scr->focused_window;
 
-	for (fl = 0; fl < 2; fl++) {
-		for (wwin = curwin; wwin; wwin = wwin->prev) {
-			if (((!fl && canReceiveFocus(wwin) > 0) || (fl && canReceiveFocus(wwin) < 0)) &&
-			    (wwin->flags.mapped || include_unmapped)) {
-				if (class_only)
-					if (!sameWindowClass(wwin, curwin))
-						continue;
-
-				if (!WFLAGP(wwin, skip_switchpanel))
-					WMAddToArray(windows, wwin);
-			}
-		}
-		wwin = curwin;
-		/* start over from the beginning of the list */
-		while (wwin->next)
-			wwin = wwin->next;
-
-		for (wwin = curwin; wwin && wwin != curwin; wwin = wwin->prev) {
-			if (((!fl && canReceiveFocus(wwin) > 0) || (fl && canReceiveFocus(wwin) < 0)) &&
-			    (wwin->flags.mapped || include_unmapped)) {
-				if (class_only)
-				    if (!sameWindowClass(wwin, curwin))
+	while (wwin) {
+		if ((canReceiveFocus(wwin) != 0) &&
+		    (wwin->flags.mapped || wwin->flags.shaded || include_unmapped)) {
+			if (class_only)
+				if (!sameWindowClass(scr->focused_window, wwin)) {
+					wwin = wwin->prev;
 					continue;
-				if (!WFLAGP(wwin, skip_switchpanel))
+				}
+			if (!WFLAGP(wwin, skip_switchpanel))
 				WMAddToArray(windows, wwin);
-			}
 		}
+		wwin = wwin->prev;
 	}
-
 	return windows;
 }
 
 static WMArray *makeWindowFlagsArray(int count)
 {
-	WMArray *flags = WMCreateArray(1);
+	WMArray *flags = WMCreateArray(count);
 	int i;
 
 	for (i = 0; i < count; i++)
-		WMAddToArray(flags, (char) 0);
+		WMAddToArray(flags, (void *) 0);
 
 	return flags;
 }
 
 WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 {
+	int wmScaleWidth, wmScaleHeight;
+	WMGetScaleBaseFromSystemFont(scr->wmscreen, &wmScaleWidth, &wmScaleHeight);
+
+	icon_size = wPreferences.switch_panel_icon_size;
+	icon_tile_size = (short int)(((float)icon_size * (float)1.2) + 0.5);
+	border_space = WMScaleY(10);
+	label_height = WMScaleY(25);
+
 	WWindow *wwin;
 	WSwitchPanel *panel = wmalloc(sizeof(WSwitchPanel));
 	WMFrame *viewport;
@@ -424,7 +410,7 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 	WMRect rect = wGetRectForHead(scr, wGetHeadForPointerLocation(scr));
 
 	panel->scr = scr;
-	panel->windows = makeWindowListArray(curwin, wPreferences.swtileImage != NULL, class_only);
+	panel->windows = makeWindowListArray(scr, wPreferences.swtileImage != NULL, class_only);
 	count = WMGetArrayItemCount(panel->windows);
 	if (count)
 		panel->flags = makeWindowFlagsArray(count);
@@ -435,12 +421,12 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 		return NULL;
 	}
 
-	width = ICON_TILE_SIZE * count;
+	width = icon_tile_size* count;
 	iconsThatFitCount = count;
 
-	if (width > rect.size.width) {
-		iconsThatFitCount = (rect.size.width - SCREEN_BORDER_SPACING) / ICON_TILE_SIZE;
-		width = iconsThatFitCount * ICON_TILE_SIZE;
+	if (width > (int)rect.size.width) {
+		iconsThatFitCount = (rect.size.width - SCREEN_BORDER_SPACING) / icon_tile_size;
+		width = iconsThatFitCount * icon_tile_size;
 	}
 
 	panel->visibleCount = iconsThatFitCount;
@@ -448,12 +434,12 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 	if (!wPreferences.swtileImage)
 		return panel;
 
-	height = LABEL_HEIGHT + ICON_TILE_SIZE;
+	height = label_height + icon_tile_size;
 
-	panel->tileTmp = RCreateImage(ICON_TILE_SIZE, ICON_TILE_SIZE, 1);
+	panel->tileTmp = RCreateImage(icon_tile_size, icon_tile_size, 1);
 	panel->tile = getTile();
 	if (panel->tile && wPreferences.swbackImage[8])
-		panel->bg = createBackImage(width + 2 * BORDER_SPACE, height + 2 * BORDER_SPACE);
+		panel->bg = createBackImage(width + 2 * border_space, height + 2 * border_space);
 
 	if (!panel->tileTmp || !panel->tile) {
 		if (panel->bg)
@@ -468,7 +454,7 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 	}
 
 	panel->white = WMWhiteColor(scr->wmscreen);
-	panel->font = WMBoldSystemFontOfSize(scr->wmscreen, 12);
+	panel->font = WMBoldSystemFontOfSize(scr->wmscreen, WMScaleY(12));
 	panel->icons = WMCreateArray(count);
 	panel->images = WMCreateArray(count);
 
@@ -481,8 +467,8 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 		WMSetViewExpandsToParent(WMWidgetView(frame), 0, 0, 0, 0);
 
 		panel->label = WMCreateLabel(panel->win);
-		WMResizeWidget(panel->label, width, LABEL_HEIGHT);
-		WMMoveWidget(panel->label, BORDER_SPACE, BORDER_SPACE + ICON_TILE_SIZE + 5);
+		WMResizeWidget(panel->label, width, label_height);
+		WMMoveWidget(panel->label, border_space, border_space + icon_tile_size+ 5);
 		WMSetLabelRelief(panel->label, WRSimple);
 		WMSetWidgetBackgroundColor(panel->label, darkGray);
 		WMSetLabelFont(panel->label, panel->font);
@@ -492,20 +478,20 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 		height += 5;
 	}
 
-	WMResizeWidget(panel->win, width + 2 * BORDER_SPACE, height + 2 * BORDER_SPACE);
+	WMResizeWidget(panel->win, width + 2 * border_space, height + 2 * border_space);
 
 	viewport = WMCreateFrame(panel->win);
-	WMResizeWidget(viewport, width, ICON_TILE_SIZE);
-	WMMoveWidget(viewport, BORDER_SPACE, BORDER_SPACE);
+	WMResizeWidget(viewport, width, icon_tile_size);
+	WMMoveWidget(viewport, border_space, border_space);
 	WMSetFrameRelief(viewport, WRFlat);
 
 	panel->iconBox = WMCreateFrame(viewport);
 	WMMoveWidget(panel->iconBox, 0, 0);
-	WMResizeWidget(panel->iconBox, ICON_TILE_SIZE * count, ICON_TILE_SIZE);
+	WMResizeWidget(panel->iconBox, icon_tile_size* count, icon_tile_size);
 	WMSetFrameRelief(panel->iconBox, WRFlat);
 
 	WM_ITERATE_ARRAY(panel->windows, wwin, i) {
-		addIconForWindow(panel, panel->iconBox, wwin, i * ICON_TILE_SIZE, 0);
+		addIconForWindow(panel, panel->iconBox, wwin, i * icon_tile_size, 0);
 	}
 
 	WMMapSubwidgets(panel->win);
@@ -522,8 +508,8 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 
 		XSetWindowBackgroundPixmap(dpy, WMWidgetXID(panel->win), pixmap);
 
-#ifdef SHAPE
-		if (mask && wShapeSupported)
+#ifdef USE_XSHAPE
+		if (mask && w_global.xext.shape.supported)
 			XShapeCombineMask(dpy, WMWidgetXID(panel->win), ShapeBounding, 0, 0, mask, ShapeSet);
 #endif
 		if (pixmap)
@@ -536,7 +522,7 @@ WSwitchPanel *wInitSwitchPanel(WScreen *scr, WWindow *curwin, Bool class_only)
 	{
 		WMPoint center;
 		center = wGetPointToCenterRectInHead(scr, wGetHeadForPointerLocation(scr),
-						     width + 2 * BORDER_SPACE, height + 2 * BORDER_SPACE);
+						     width + 2 * border_space, height + 2 * border_space);
 		WMMoveWidget(panel->win, center.x, center.y);
 	}
 
@@ -558,7 +544,7 @@ void wSwitchPanelDestroy(WSwitchPanel *panel)
 		Window info_win = panel->scr->info_window;
 		XEvent ev;
 		ev.xclient.type = ClientMessage;
-		ev.xclient.message_type = _XA_WM_IGNORE_FOCUS_EVENTS;
+		ev.xclient.message_type = w_global.atom.wm.ignore_focus_events;
 		ev.xclient.format = 32;
 		ev.xclient.data.l[0] = True;
 
@@ -631,7 +617,7 @@ WWindow *wSwitchPanelSelectNext(WSwitchPanel *panel, int back, int ignore_minimi
 			else
 				panel->current++;
 
-			panel->current= (count + panel->current) % count;
+			panel->current = (count + panel->current) % count;
 			wwin = WMGetFromArray(panel->windows, panel->current);
 
 			if (!class_only)
@@ -691,9 +677,9 @@ WWindow *wSwitchPanelSelectFirst(WSwitchPanel *panel, int back)
 	title = wwin->frame->title;
 
 	if (panel->win) {
-		WM_ITERATE_ARRAY(panel->windows, wwin, i) {
+		for (WMArrayFirst(panel->windows, &(i)); (i) != WANotFound; WMArrayNext(panel->windows, &(i)))
 			changeImage(panel, i, i == panel->current, False, False);
-		}
+
 		drawTitle(panel, panel->current, title);
 	}
 
