@@ -110,6 +110,10 @@ WTexSolid *wTextureMakeSolid(WScreen * scr, XColor * color)
 
 static int dummyErrorHandler(Display * foo, XErrorEvent * bar)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) foo;
+	(void) bar;
+
 	return 0;
 }
 
@@ -537,8 +541,6 @@ void wDrawBevel(Drawable d, unsigned width, unsigned height, WTexSolid * texture
 	dim = texture->dim_gc;
 	dark = texture->dark_gc;
 	switch (relief) {
-	case WREL_FLAT:
-		return;
 	case WREL_MENUENTRY:
 	case WREL_RAISED:
 	case WREL_ICON:
