@@ -13,10 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
- *  USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 
@@ -160,15 +159,12 @@ typedef union WTexture {
 
 
 WTexSolid *wTextureMakeSolid(WScreen*, XColor*);
-WTexGradient *wTextureMakeGradient(WScreen*, int, RColor*, RColor*);
+WTexGradient *wTextureMakeGradient(WScreen*, int, const RColor*, const RColor*);
 WTexMGradient *wTextureMakeMGradient(WScreen*, int, RColor**);
-WTexTGradient *wTextureMakeTGradient(WScreen*, int, RColor*, RColor*, char *, int);
-WTexIGradient *wTextureMakeIGradient(WScreen*, int, RColor[], int, RColor[]);
-WTexPixmap *wTextureMakePixmap(WScreen *scr, int style, char *pixmap_file,
+WTexTGradient *wTextureMakeTGradient(WScreen*, int, const RColor*, const RColor*, const char *, int);
+WTexIGradient *wTextureMakeIGradient(WScreen*, int, const RColor[], int, const RColor[]);
+WTexPixmap *wTextureMakePixmap(WScreen *scr, int style, const char *pixmap_file,
                                XColor *color);
-#ifdef TEXTURE_PLUGIN
-WTexFunction *wTextureMakeFunction(WScreen*, char *, char *, int, char **);
-#endif
 void wTextureDestroy(WScreen*, WTexture*);
 void wTexturePaint(WTexture *, Pixmap *, WCoreWindow*, int, int);
 void wTextureRender(WScreen*, WTexture*, Pixmap*, int, int, int);
