@@ -17,7 +17,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #ifndef WMCONFIG_H_
@@ -32,15 +33,6 @@
  * Also check the features you can enable through configure.
  */
 
-/* If you want animations for iconification, shading, icon arrangement etc. */
-#define ANIMATIONS
-
-/* support for XDND drop in the Dock. Experimental */
-/*#define XDND*/
-
-/* support for Motif window manager (mwm) window hints */
-#define MWM_HINTS
-
 /*
  * Undefine BALLOON_TEXT if you don't want balloons for showing extra
  * information, like window titles that are not fully visible.
@@ -144,7 +136,15 @@
 
 /* pixmap path */
 #define DEF_PIXMAP_PATHS \
-    "(\"~/pixmaps\",\"~/GNUstep/Library/WindowMaker/Pixmaps\",\""PIXMAPDIR"\")"
+	"("                                                        \
+		"\"~/GNUstep/Library/WindowMaker/Pixmaps\","       \
+		"\"~/GNUstep/Library/WindowMaker/Backgrounds\","   \
+		"\"~/GNUstep/Library/WindowMaker/CachedPixmaps\"," \
+		"\"~/pixmaps\","                                   \
+		"\""PKGDATADIR"/Pixmaps\","                        \
+		"\""PKGDATADIR"/Backgrounds\","                    \
+		"\""PIXMAPDIR"\""                                  \
+	")"
 
 #ifdef USER_MENU
 #define GLOBAL_USER_MENU_PATH PKGDATADIR"/UserMenus"
@@ -154,7 +154,15 @@
 
 /* icon path */
 #define DEF_ICON_PATHS \
-    "(\"~/pixmaps\",\"~/GNUstep/Library/Icons\",\"/usr/include/X11/pixmaps/\",\""PIXMAPDIR"\")"
+	"("                                                        \
+		"\"~/GNUstep/Library/Icons\","                     \
+		"\"~/GNUstep/Library/WindowMaker/Pixmaps\","       \
+		"\"~/GNUstep/Library/WindowMaker/CachedPixmaps\"," \
+		"\"~/pixmaps\","                                   \
+		"\""PKGDATADIR"/Icons\","                          \
+		"\""PKGDATADIR"/Pixmaps\","                        \
+		"\""PIXMAPDIR"\""                                  \
+	")"
 
 /* window title to use for untitled windows */
 #define DEF_WINDOW_TITLE "Untitled"
@@ -163,13 +171,12 @@
 #define DEF_FRAME_COLOR   "white"
 
 /* default fonts */
-#define DEF_TITLE_FONT          "\"Trebuchet MS,sans serif:bold:pixelsize=12\""
-#define DEF_MENU_TITLE_FONT     "\"Trebuchet MS,sans serif:bold:pixelsize=12\""
-#define DEF_MENU_ENTRY_FONT     "\"Trebuchet MS,sans serif:pixelsize=12\""
-#define DEF_ICON_TITLE_FONT     "\"Arial,sans serif:pixelsize=9\""
-#define DEF_CLIP_TITLE_FONT     "\"Verdana:bold:pixelsize=10\""
-#define DEF_INFO_TEXT_FONT      "\"Trebuchet MS,sans serif:pixelsize=12\""
-#define DEF_WORKSPACE_NAME_FONT "\"Trebuchet MS,sans serif:pixelsize=24\""
+#define DEF_TITLE_FONT          "\"Sans:bold:pixelsize=12\""
+#define DEF_MENU_TITLE_FONT     "\"Sans:bold:pixelsize=12\""
+#define DEF_MENU_ENTRY_FONT     "\"Sans:pixelsize=12\""
+#define DEF_ICON_TITLE_FONT     "\"Sans:pixelsize=9\""
+#define DEF_CLIP_TITLE_FONT     "\"Sans:bold:pixelsize=10\""
+#define DEF_WORKSPACE_NAME_FONT "\"Sans:pixelsize=24\""
 
 /* line width of the move/resize frame */
 #define DEF_FRAME_THICKNESS              1
@@ -196,7 +203,7 @@
 #define SINGLE_MENULEVEL
 
 /* max. time to spend doing animations in seconds. If the animation
- * time exceeds this value, it is immediately finished. Usefull for
+ * time exceeds this value, it is immediately finished. Useful for
  * moments of high-load. DO NOT set *_DELAY_{Z,T,F} to zero!
  */
 #define MAX_ANIMATION_TIME	         1
@@ -300,20 +307,6 @@
  * a docked icon must be dragged out to detach it */
 #define DOCK_DETTACH_THRESHOLD	3
 
-/* Delay (in ms) after which the clip will autocollapse when leaved */
-#define AUTO_COLLAPSE_DELAY     1000
-
-/* Delay (in ms) after which the clip will autoexpand when entered.
- * Set this to zero if you want instant expanding. */
-#define AUTO_EXPAND_DELAY       600
-
-/* Delay (in ms) after which the clip will be lowered when leaved */
-#define AUTO_LOWER_DELAY        1000
-
-/* Delay (in ms) after which the clip will be raised when entered.
- * Set this to zero if you want instant raise. */
-#define AUTO_RAISE_DELAY        600
-
 /* Max. number of icons the dock and clip can have */
 #define DOCK_MAX_ICONS		32
 
@@ -328,7 +321,7 @@
 
 #define MAX_WORKSPACENAME_WIDTH	64
 /* max width of window title in window list */
-#define MAX_WINDOWLIST_WIDTH	160
+#define MAX_WINDOWLIST_WIDTH	400
 
 #ifndef HAVE_INOTIFY
 /* Check defaults database for changes every this many milliseconds */
@@ -340,9 +333,6 @@
 /* don't put titles in miniwindows */
 #undef NO_MINIWINDOW_TITLES
 
-#define FRAME_BORDER_COLOR "black"
-#define FRAME_SELECTED_BORDER_COLOR "white"
-
 /* for boxes with high mouse sampling rates (SGI) */
 #define DELAY_BETWEEN_MOUSE_SAMPLING  10
 
@@ -353,11 +343,9 @@
 
 /* number of window shortcuts */
 #define MAX_WINDOW_SHORTCUTS      10
-#define WM_PI                     3.14159265358979323846
 #define MIN_TITLEFONT_HEIGHT(h)   ((h)>14 ? (h) : 14)
 #define TITLEBAR_HEIGHT           18  /* window's titlebar height */
 #define RESIZEBAR_HEIGHT          8   /* height of the resizebar */
-#define FRAME_BORDER_WIDTH        1   /* width of window border for frames */
 #define RESIZEBAR_MIN_WIDTH       20  /* min width of handles-corner_width */
 #define RESIZEBAR_CORNER_WIDTH    28  /* width of the corner of resizebars */
 #define MENU_INDICATOR_SPACE      12
@@ -380,7 +368,7 @@
 #endif
 
 /* some rules */
-#ifndef SHAPE
+#ifndef USE_XSHAPE
 #undef SHAPED_BALLOON
 #endif
 
@@ -414,11 +402,5 @@
 #define M_(text) (text)
 #endif
 
-#if defined(__GNUC__) && !defined(__STRICT_ANSI__)
-#define INLINE inline
-#else
-#define INLINE
-#endif
-
 #endif /* WMCONFIG_H_ */
 
