@@ -23,7 +23,7 @@
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#ifdef SHAPE
+#ifdef USE_XSHAPE
 #include <X11/extensions/shape.h>
 #endif
 #ifdef KEEP_XKB_LOCK_STATUS
@@ -65,28 +65,13 @@
 #include "winmenu.h"
 #include "osdep.h"
 
-#ifdef MWM_HINTS
+#ifdef USE_MWM_HINTS
 # include "motif.h"
 #endif
 #include "wmspec.h"
 
 #define MOD_MASK wPreferences.modifier_mask
 
-/****** Global Variables ******/
-extern WShortKey wKeyBindings[WKBD_LAST];
-
-#ifdef SHAPE
-extern Bool wShapeSupported;
-#endif
-
-/* contexts */
-extern XContext wWinContext;
-
-/* protocol atoms */
-extern Atom _XA_WM_DELETE_WINDOW;
-extern Atom _XA_GNUSTEP_WM_MINIATURIZE_WINDOW;
-extern Atom _XA_WINDOWMAKER_STATE;
-extern Time LastTimestamp;
 
 /***** Local Stuff *****/
 static WWindowState *windowState = NULL;
@@ -152,7 +137,7 @@ WWindow *wWindowFor(Window window)
 	if (window == None)
 		return NULL;
 
-	if (XFindContext(dpy, window, wWinContext, (XPointer *) & desc) == XCNOENT)
+	if (XFindContext(dpy, window, w_global.context.client_win, (XPointer *) & desc) == XCNOENT)
 		return NULL;
 
 	if (desc->parent_type == WCLASS_WINDOW)
@@ -232,7 +217,7 @@ void wWindowDestroy(WWindow *wwin)
 	if (wwin->cmap_windows)
 		XFree(wwin->cmap_windows);
 
-	XDeleteContext(dpy, wwin->client_win, wWinContext);
+	XDeleteContext(dpy, wwin->client_win, w_global.context.client_win);
 
 	if (wwin->frame)
 		wFrameWindowDestroy(wwin->frame);
@@ -303,12 +288,39 @@ static void setupGNUstepHints(WWindow *wwin, GNUstepWMAttributes *gs_hints)
 		wwin->client_flags.no_appicon = 1;
 }
 
+static void discard_hints_from_gtk(WWindow *wwin)
+{
+	Atom type;
+	int format;
+	unsigned long nb_item, nb_remain;
+	unsigned char *result;
+	int status;
+
+	status = XGetWindowProperty(dpy, wwin->client_win, w_global.atom.desktop.gtk_object_path, 0, 16, False,
+	                            AnyPropertyType, &type, &format, &nb_item, &nb_remain, &result);
+	if (status != Success)
+		return;
+
+	/* If we're here, that means the Property exists. We don't care what is inside, it means it is a GTK-based application */
+
+	if (result != NULL)
+		XFree(result);
+
+	/* GTK is asking to remove these decorations: */
+	wwin->client_flags.no_titlebar = 0;
+	wwin->client_flags.no_close_button = 0;
+	wwin->client_flags.no_miniaturize_button = 0;
+	wwin->client_flags.no_resizebar = 0;
+}
+
 void wWindowSetupInitialAttributes(WWindow *wwin, int *level, int *workspace)
 {
 	WScreen *scr = wwin->screen_ptr;
 
 	/* sets global default stuff */
-	wDefaultFillAttributes(wwin->wm_instance, wwin->wm_class, &wwin->client_flags, NULL, True);
+	wDefaultFillAttributes(wwin->wm_instance, wwin->wm_class, &wwin->user_flags, NULL, True);
+	wwin->defined_user_flags = wwin->user_flags;
+
 	/*
 	 * Decoration setting is done in this precedence (lower to higher)
 	 * - use global default in the resource database
@@ -317,25 +329,25 @@ void wWindowSetupInitialAttributes(WWindow *wwin, int *level, int *workspace)
 	 * - set hints specified for the app in the resource DB
 	 *
 	 */
-	WSETUFLAG(wwin, broken_close, 0);
+	wwin->client_flags.broken_close = 0;
 
 	if (wwin->protocols.DELETE_WINDOW)
-		WSETUFLAG(wwin, kill_close, 0);
+		wwin->client_flags.kill_close = 0;
 	else
-		WSETUFLAG(wwin, kill_close, 1);
+		wwin->client_flags.kill_close = 1;
 
 	/* transients can't be iconified or maximized */
 	if (wwin->transient_for != None && wwin->transient_for != scr->root_win) {
-		WSETUFLAG(wwin, no_miniaturizable, 1);
-		WSETUFLAG(wwin, no_miniaturize_button, 1);
+		wwin->client_flags.no_miniaturizable = 1;
+		wwin->client_flags.no_miniaturize_button = 1;
 	}
 
 	/* if the window can't be resized, remove the resizebar */
 	if (wwin->normal_hints->flags & (PMinSize | PMaxSize)
 	    && (wwin->normal_hints->min_width == wwin->normal_hints->max_width)
 	    && (wwin->normal_hints->min_height == wwin->normal_hints->max_height)) {
-		WSETUFLAG(wwin, no_resizable, 1);
-		WSETUFLAG(wwin, no_resizebar, 1);
+		wwin->client_flags.no_resizable = 1;
+		wwin->client_flags.no_resizebar = 1;
 	}
 
 	/* set GNUstep window attributes */
@@ -358,12 +370,15 @@ void wWindowSetupInitialAttributes(WWindow *wwin, int *level, int *workspace)
 		int tmp_workspace = -1;
 		int tmp_level = INT_MIN;	/* INT_MIN is never used by the window levels */
 
-#ifdef MWM_HINTS
+#ifdef USE_MWM_HINTS
 		wMWMCheckClientHints(wwin);
-#endif				/* MWM_HINTS */
+#endif	/* USE_MWM_HINTS */
 
 		wNETWMCheckClientHints(wwin, &tmp_level, &tmp_workspace);
 
+		if (wPreferences.ignore_gtk_decoration_hints)
+			discard_hints_from_gtk(wwin);
+
 		/* window levels are between INT_MIN+1 and INT_MAX, so if we still
 		 * have INT_MIN that means that no window level was requested. -Dan
 		 */
@@ -397,6 +412,20 @@ void wWindowSetupInitialAttributes(WWindow *wwin, int *level, int *workspace)
 	 */
 	wDefaultFillAttributes(wwin->wm_instance, wwin->wm_class, &wwin->user_flags,
 			       &wwin->defined_user_flags, False);
+
+	/* Restore decoration if the user has enabled the
+	 * IgnoreDecorationChanges option */
+	if (wwin->user_flags.ignore_decoration_changes) {
+		WSETUFLAG(wwin, no_titlebar, 0);
+		WSETUFLAG(wwin, no_resizable, 0);
+		WSETUFLAG(wwin, no_miniaturizable, 0);
+		WSETUFLAG(wwin, no_resizebar, 0);
+		WSETUFLAG(wwin, no_close_button, 0);
+		WSETUFLAG(wwin, no_miniaturize_button, 0);
+		WSETUFLAG(wwin, no_border, 0);
+		WSETUFLAG(wwin, no_movable, 0);
+	}
+
 	/*
 	 * Sanity checks for attributes that depend on other attributes
 	 */
@@ -416,7 +445,9 @@ void wWindowSetupInitialAttributes(WWindow *wwin, int *level, int *workspace)
 	    && wwin->user_flags.floating && wwin->defined_user_flags.floating)
 		wwin->user_flags.sunken = 0;
 
-	WSETUFLAG(wwin, no_shadeable, WFLAGP(wwin, no_titlebar));
+	/* A window that does not have a title cannot be Shaded and we don't let user override this */
+	wwin->client_flags.no_shadeable = WFLAGP(wwin, no_titlebar);
+	wwin->defined_user_flags.no_shadeable = 0;
 
 	/* windows that have takefocus=False shouldn't take focus at all */
 	if (wwin->focus_mode == WFM_NO_INPUT)
@@ -627,10 +658,10 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 	else if (!wFetchName(dpy, window, &title))
 		title = NULL;
 
-	XSaveContext(dpy, window, wWinContext, (XPointer) & wwin->client_descriptor);
+	XSaveContext(dpy, window, w_global.context.client_win, (XPointer) & wwin->client_descriptor);
 
-#ifdef SHAPE
-	if (wShapeSupported) {
+#ifdef USE_XSHAPE
+	if (w_global.xext.shape.supported) {
 		int junk;
 		unsigned int ujunk;
 		int b_shaped;
@@ -739,23 +770,22 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 	wwin->orig_main_window = wwin->main_window;
 
 	if (wwin->flags.is_gnustep)
-		WSETUFLAG(wwin, shared_appicon, 0);
+		wwin->client_flags.shared_appicon = 0;
 
 	if (wwin->main_window) {
-		extern Atom _XA_WINDOWMAKER_MENU;
 		XTextProperty text_prop;
 
-		if (XGetTextProperty(dpy, wwin->main_window, &text_prop, _XA_WINDOWMAKER_MENU))
-			WSETUFLAG(wwin, shared_appicon, 0);
+		if (XGetTextProperty(dpy, wwin->main_window, &text_prop, w_global.atom.wmaker.menu))
+			wwin->client_flags.shared_appicon = 0;
 	}
 
 	if (wwin->flags.is_dockapp)
-		WSETUFLAG(wwin, shared_appicon, 0);
+		wwin->client_flags.shared_appicon = 0;
 
 	if (wwin->main_window) {
             WApplication *app = wApplicationOf(wwin->main_window);
             if (app && app->app_icon)
-		WSETUFLAG(wwin, shared_appicon, 0);
+		wwin->client_flags.shared_appicon = 0;
         }
 
 	if (!withdraw && wwin->main_window && WFLAGP(wwin, shared_appicon)) {
@@ -765,7 +795,7 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 
 #define ADEQUATE(x) ((x)!=None && (x)!=wwin->client_win && (x)!=fPtr->leader)
 
-		/* // only enter here if PropGetWMClass() succeds */
+		/* // only enter here if PropGetWMClass() succeeds */
 		PropGetWMClass(wwin->main_window, &class, &instance);
 		buffer = StrConcatDot(instance, class);
 
@@ -948,9 +978,8 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 	wWindowConstrainSize(wwin, &width, &height);
 
 	/* do not ask for window placement if the window is
-	 * transient, during startup, if the initial workspace is another one
-	 * or if the window wants to start iconic.
-	 * If geometry was saved, restore it. */
+	 * transient, during startup, or if the window wants
+	 * to start iconic.  If geometry was saved, restore it. */
 	{
 		Bool dontBring = False;
 
@@ -959,7 +988,6 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 			y = win_state->state->y;
 		} else if ((wwin->transient_for == None || wPreferences.window_placement != WPM_MANUAL)
 			   && !scr->flags.startup
-			   && workspace == scr->current_workspace
 			   && !wwin->flags.miniaturized
 			   && !wwin->flags.maximized && !(wwin->normal_hints->flags & (USPosition | PPosition))) {
 
@@ -1096,6 +1124,8 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 	wwin->frame->flags.is_client_window_frame = 1;
 	wwin->frame->flags.justification = wPreferences.title_justification;
 
+	wNETWMCheckInitialFrameState(wwin);
+
 	/* setup button images */
 	wWindowUpdateButtonImages(wwin);
 
@@ -1223,7 +1253,7 @@ WWindow *wManageWindow(WScreen *scr, Window window)
 		     * the window focusing (if the mouse is over that window)
 		     * will be processed by wmaker.
 		     * But since this event will be rather delayed
-		     * (step 3 has a large delay) the time when the event ocurred
+		     * (step 3 has a large delay) the time when the event occurred
 		     * and when it is processed, the client that owns that window
 		     * will reject the XSetInputFocus() for it.
 		     */
@@ -1334,10 +1364,10 @@ WWindow *wManageInternalWindow(WScreen *scr, Window window, Window owner,
 
 	wwin->flags.internal_window = 1;
 
-	WSETUFLAG(wwin, omnipresent, 1);
-	WSETUFLAG(wwin, no_shadeable, 1);
-	WSETUFLAG(wwin, no_resizable, 1);
-	WSETUFLAG(wwin, no_miniaturizable, 1);
+	wwin->client_flags.omnipresent = 1;
+	wwin->client_flags.no_shadeable = 1;
+	wwin->client_flags.no_resizable = 1;
+	wwin->client_flags.no_miniaturizable = 1;
 
 	wwin->focus_mode = WFM_PASSIVE;
 	wwin->client_win = window;
@@ -1367,7 +1397,7 @@ WWindow *wManageInternalWindow(WScreen *scr, Window window, Window owner,
 					 scr->resizebar_texture, scr->window_title_color, &scr->title_font,
 					 scr->w_depth, scr->w_visual, scr->w_colormap);
 
-	XSaveContext(dpy, window, wWinContext, (XPointer) & wwin->client_descriptor);
+	XSaveContext(dpy, window, w_global.context.client_win, (XPointer) & wwin->client_descriptor);
 
 	wwin->frame->flags.is_client_window_frame = 1;
 	wwin->frame->flags.justification = wPreferences.title_justification;
@@ -1472,6 +1502,11 @@ void wUnmanageWindow(WWindow *wwin, Bool restore, Bool destroyed)
 	if (wwin->flags.menu_open_for_me)
 		CloseWindowMenu(scr);
 
+	/* Don't restore focus to this window after a window exits
+	 * fullscreen mode */
+	if (scr->bfs_focused_window == wwin)
+		scr->bfs_focused_window = NULL;
+
 	if (!destroyed) {
 		if (!wwin->flags.internal_window)
 			XRemoveFromSaveSet(dpy, wwin->client_win);
@@ -1639,6 +1674,61 @@ void wWindowUnmap(WWindow *wwin)
 	XUnmapWindow(dpy, wwin->frame->core->window);
 }
 
+void wWindowSingleFocus(WWindow *wwin)
+{
+	WScreen *scr;
+	int x, y, move = 0;
+
+	if (!wwin)
+		return;
+
+	scr = wwin->screen_ptr;
+	wMakeWindowVisible(wwin);
+
+	x = wwin->frame_x;
+	y = wwin->frame_y;
+
+	/* bring window back to visible area */
+	move = wScreenBringInside(scr, &x, &y, wwin->frame->core->width, wwin->frame->core->height);
+
+	if (move) {
+		wWindowConfigure(wwin, x, y, wwin->client.width, wwin->client.height);
+	}
+}
+
+void wWindowFocusPrev(WWindow *wwin, Bool inSameWorkspace)
+{
+	WWindow *tmp;
+
+	if (!wwin || !wwin->prev)
+		return;
+
+	tmp = wwin;
+	while (tmp->prev)
+		tmp = tmp->prev;
+
+	if (inSameWorkspace)
+		while (tmp && (tmp->frame->workspace != wwin->frame->workspace))
+			tmp = tmp->next;
+
+	wWindowSingleFocus(tmp);
+}
+
+void wWindowFocusNext(WWindow *wwin, Bool inSameWorkspace)
+{
+	WWindow *tmp;
+
+	if (!wwin || !wwin->prev)
+		return;
+
+	tmp = wwin->prev;
+	if (inSameWorkspace)
+		while (tmp && (tmp->frame->workspace != wwin->frame->workspace))
+			tmp = tmp->prev;
+
+	wWindowSingleFocus(tmp);
+}
+
 void wWindowFocus(WWindow *wwin, WWindow *owin)
 {
 	WWindow *nowner;
@@ -1997,6 +2087,14 @@ void wWindowConfigure(WWindow *wwin, int req_x, int req_y, int req_width, int re
 	int synth_notify = False;
 	int resize;
 
+	/* if window size is guaranteed to fail - fix it to some reasonable
+	 * defaults */
+	if (req_height > SHRT_MAX)
+		req_height = 480;
+
+	if (req_width > SHRT_MAX)
+		req_height = 640;
+
 	resize = (req_width != wwin->client.width || req_height != wwin->client.height);
 	/*
 	 * if the window is being moved but not resized then
@@ -2051,8 +2149,8 @@ void wWindowConfigure(WWindow *wwin, int req_x, int req_y, int req_width, int re
 		wwin->client.x += wwin->screen_ptr->frame_border_width;
 		wwin->client.y += wwin->screen_ptr->frame_border_width;
 	}
-#ifdef SHAPE
-	if (wShapeSupported && wwin->flags.shaped && resize)
+#ifdef USE_XSHAPE
+	if (w_global.xext.shape.supported && wwin->flags.shaped && resize)
 		wWindowSetShape(wwin);
 #endif
 
@@ -2126,7 +2224,7 @@ void wWindowUpdateButtonImages(WWindow *wwin)
 			}
 
 			if (!fwin->lbutton_image) {
-				fwin->lbutton_image = wPixmapCreate(scr, pixmap, mask);
+				fwin->lbutton_image = wPixmapCreate(pixmap, mask);
 				fwin->lbutton_image->client_owned = 1;
 				fwin->lbutton_image->client_owned_mask = 1;
 			}
@@ -2167,7 +2265,7 @@ void wWindowUpdateButtonImages(WWindow *wwin)
 			}
 
 			if (!fwin->rbutton_image) {
-				fwin->rbutton_image = wPixmapCreate(scr, pixmap, mask);
+				fwin->rbutton_image = wPixmapCreate(pixmap, mask);
 				fwin->rbutton_image->client_owned = 1;
 				fwin->rbutton_image->client_owned_mask = 1;
 			}
@@ -2275,14 +2373,14 @@ void wWindowConfigureBorders(WWindow *wwin)
 		if (flags != 0)
 			wFrameWindowHideButton(wwin->frame, flags);
 
-#ifdef SHAPE
-		if (wShapeSupported && wwin->flags.shaped)
+#ifdef USE_XSHAPE
+		if (w_global.xext.shape.supported && wwin->flags.shaped)
 			wWindowSetShape(wwin);
 #endif
 	}
 }
 
-void wWindowSaveState(WWindow * wwin)
+void wWindowSaveState(WWindow *wwin)
 {
 	long data[10];
 	int i;
@@ -2310,8 +2408,9 @@ void wWindowSaveState(WWindow * wwin)
 		    WMCountInArray(wwin->screen_ptr->shortcutWindows[i], wwin))
 			data[9] |= 1 << i;
 	}
-	XChangeProperty(dpy, wwin->client_win, _XA_WINDOWMAKER_STATE,
-			_XA_WINDOWMAKER_STATE, 32, PropModeReplace, (unsigned char *)data, 10);
+
+	XChangeProperty(dpy, wwin->client_win, w_global.atom.wmaker.state,
+			w_global.atom.wmaker.state, 32, PropModeReplace, (unsigned char *)data, 10);
 }
 
 static int getSavedState(Window window, WSavedState ** state)
@@ -2322,12 +2421,17 @@ static int getSavedState(Window window, WSavedState ** state)
 	unsigned long bytes_after_ret;
 	long *data;
 
-	if (XGetWindowProperty(dpy, window, _XA_WINDOWMAKER_STATE, 0, 10,
-			       True, _XA_WINDOWMAKER_STATE,
+	if (XGetWindowProperty(dpy, window, w_global.atom.wmaker.state, 0, 10,
+			       True, w_global.atom.wmaker.state,
 			       &type_ret, &fmt_ret, &nitems_ret, &bytes_after_ret,
 			       (unsigned char **)&data) != Success || !data || nitems_ret < 10)
 		return 0;
 
+	if (type_ret != w_global.atom.wmaker.state) {
+		XFree(data);
+		return 0;
+	}
+
 	*state = wmalloc(sizeof(WSavedState));
 
 	(*state)->workspace = data[0];
@@ -2343,13 +2447,10 @@ static int getSavedState(Window window, WSavedState ** state)
 
 	XFree(data);
 
-	if (*state && type_ret == _XA_WINDOWMAKER_STATE)
-		return 1;
-	else
-		return 0;
+	return 1;
 }
 
-#ifdef SHAPE
+#ifdef USE_XSHAPE
 void wWindowClearShape(WWindow * wwin)
 {
 	XShapeCombineMask(dpy, wwin->frame->core->window, ShapeBounding,
@@ -2433,7 +2534,7 @@ void wWindowSetShape(WWindow * wwin)
 			   ShapeBounding, (count > 0 ? ShapeUnion : ShapeSet));
 	XFlush(dpy);
 }
-#endif				/* SHAPE */
+#endif				/* USE_XSHAPE */
 
 /* ====================================================================== */
 
@@ -2493,7 +2594,7 @@ void wWindowResetMouseGrabs(WWindow * wwin)
 	/* Mouse grabs can't be done on the client window because of
 	 * ICCCM and because clients that try to do the same will crash.
 	 *
-	 * But there is a problem wich makes tbar buttons of unfocused
+	 * But there is a problem which makes tbar buttons of unfocused
 	 * windows not usable as the click goes to the frame window instead
 	 * of the button itself. Must figure a way to fix that.
 	 */
@@ -2572,7 +2673,19 @@ WMagicNumber wWindowAddSavedState(const char *instance, const char *class,
 	return wstate;
 }
 
-#define SAME(x, y) (((x) && (y) && !strcmp((x), (y))) || (!(x) && !(y)))
+static inline int is_same(const char *x, const char *y)
+{
+	if ((x == NULL) && (y == NULL))
+		return 1;
+
+	if ((x == NULL) || (y == NULL))
+		return 0;
+
+	if (strcmp(x, y) == 0)
+		return 1;
+	else
+		return 0;
+}
 
 WMagicNumber wWindowGetSavedState(Window win)
 {
@@ -2588,8 +2701,9 @@ WMagicNumber wWindowGetSavedState(Window win)
 
 	if (PropGetWMClass(win, &class, &instance)) {
 		while (wstate) {
-			if (SAME(instance, wstate->instance) &&
-			    SAME(class, wstate->class) && SAME(command, wstate->command)) {
+			if (is_same(instance, wstate->instance) &&
+			    is_same(class, wstate->class) &&
+			    is_same(command, wstate->command)) {
 				break;
 			}
 			wstate = wstate->next;
@@ -2685,6 +2799,9 @@ static void resizebarMouseDown(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = data;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
 #ifndef NUMLOCK_HACK
 	if ((event->xbutton.state & ValidModMask)
 	    != (event->xbutton.state & ~LockMask)) {
@@ -2693,7 +2810,7 @@ static void resizebarMouseDown(WCoreWindow *sender, void *data, XEvent *event)
 	}
 #endif
 
-	event->xbutton.state &= ValidModMask;
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	CloseWindowMenu(wwin->screen_ptr);
 
@@ -2727,7 +2844,10 @@ static void titlebarDblClick(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = data;
 
-	event->xbutton.state &= ValidModMask;
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	if (event->xbutton.button == Button1) {
 		if (event->xbutton.state == 0) {
@@ -2755,7 +2875,7 @@ static void titlebarDblClick(WCoreWindow *sender, void *data, XEvent *event)
 				int ndir = dir ^ wwin->flags.maximized;
 
 				if (ndir != 0)
-					wMaximizeWindow(wwin, ndir);
+					wMaximizeWindow(wwin, ndir, wGetHeadForWindow(wwin));
 				else
 					wUnmaximizeWindow(wwin);
 			}
@@ -2791,7 +2911,7 @@ static void frameMouseDown(WObjDescriptor *desc, XEvent *event)
 		resize_height_increment = wPreferences.resize_increment;
 	}
 
-	event->xbutton.state &= ValidModMask;
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	CloseWindowMenu(wwin->screen_ptr);
 
@@ -2842,12 +2962,15 @@ static void titlebarMouseDown(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = (WWindow *) data;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
 #ifndef NUMLOCK_HACK
 	if ((event->xbutton.state & ValidModMask) != (event->xbutton.state & ~LockMask))
 		wwarning(_("The NumLock, ScrollLock or similar key seems to be turned on. "
 			   "Turn it off or some mouse actions and keyboard shortcuts will not work."));
 #endif
-	event->xbutton.state &= ValidModMask;
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	CloseWindowMenu(wwin->screen_ptr);
 
@@ -2905,7 +3028,10 @@ static void windowCloseClick(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = data;
 
-	event->xbutton.state &= ValidModMask;
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	CloseWindowMenu(wwin->screen_ptr);
 
@@ -2918,7 +3044,8 @@ static void windowCloseClick(WCoreWindow *sender, void *data, XEvent *event)
 	} else {
 		if (wwin->protocols.DELETE_WINDOW && event->xbutton.state == 0) {
 			/* send delete message */
-			wClientSendProtocol(wwin, _XA_WM_DELETE_WINDOW, LastTimestamp);
+			wClientSendProtocol(wwin, w_global.atom.wm.delete_window,
+									  w_global.timestamp.last_event);
 		}
 	}
 }
@@ -2927,6 +3054,9 @@ static void windowCloseDblClick(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = data;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
 	CloseWindowMenu(wwin->screen_ptr);
 
 	if (event->xbutton.button < Button1 || event->xbutton.button > Button3)
@@ -2934,7 +3064,8 @@ static void windowCloseDblClick(WCoreWindow *sender, void *data, XEvent *event)
 
 	/* send delete message */
 	if (wwin->protocols.DELETE_WINDOW)
-		wClientSendProtocol(wwin, _XA_WM_DELETE_WINDOW, LastTimestamp);
+		wClientSendProtocol(wwin, w_global.atom.wm.delete_window,
+								  w_global.timestamp.last_event);
 	else
 		wClientKill(wwin);
 }
@@ -2947,6 +3078,9 @@ static void windowLanguageClick(WCoreWindow *sender, void *data, XEvent *event)
 	WScreen *scr = fwin->screen_ptr;
 	int tl;
 
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
 	if (event->xbutton.button != Button1 && event->xbutton.button != Button3)
 		return;
 	tl = wwin->frame->languagemode;
@@ -2966,7 +3100,10 @@ static void windowIconifyClick(WCoreWindow *sender, void *data, XEvent *event)
 {
 	WWindow *wwin = data;
 
-	event->xbutton.state &= ValidModMask;
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) sender;
+
+	event->xbutton.state &= w_global.shortcut.modifiers_mask;
 
 	CloseWindowMenu(wwin->screen_ptr);
 
@@ -2974,7 +3111,8 @@ static void windowIconifyClick(WCoreWindow *sender, void *data, XEvent *event)
 		return;
 
 	if (wwin->protocols.MINIATURIZE_WINDOW && event->xbutton.state == 0) {
-		wClientSendProtocol(wwin, _XA_GNUSTEP_WM_MINIATURIZE_WINDOW, LastTimestamp);
+		wClientSendProtocol(wwin, w_global.atom.gnustep.wm_miniaturize_window,
+								  w_global.timestamp.last_event);
 	} else {
 		WApplication *wapp;
 		if ((event->xbutton.state & ControlMask) || (event->xbutton.button == Button3)) {
