@@ -54,7 +54,7 @@ extern int XpmCreatePixmapFromData(Display *, Drawable, char **, Pixmap *, Pixma
 #include "wmiv.h"
 #endif
 
-#define DEBUG 0
+#define WMIV_DEBUG 0
 #define FILE_SEPARATOR '/'
 
 Display *dpy;
@@ -513,7 +513,7 @@ int change_image(int way)
 				current_index = max_index;
 			}
 		}
-		if (DEBUG)
+		if (WMIV_DEBUG)
 			fprintf(stderr, "current file is> %s\n", (char *)current_link->data);
 		img = load_oriented_image(ctx, current_link->data, 0);
 
@@ -789,7 +789,7 @@ int main(int argc, char **argv)
 	merge_with_background(img);
 	rescale_image();
 
-	if (DEBUG)
+	if (WMIV_DEBUG)
 		fprintf(stderr, "display size: %dx%d\n", max_width, max_height);
 
 	win = XCreateSimpleWindow(dpy, DefaultRootWindow(dpy), 0, 0,
@@ -842,7 +842,14 @@ int main(int argc, char **argv)
 		if (e.type == ClientMessage) {
 			if (e.xclient.data.l[0] == delWindow)
 				quit = 1;
-				break;
+
+			/*
+			 * This break could be related to all ClientMessages or
+			 * related to delWindow. Before the patch about this comment
+			 * the break was indented with one tab more (at the same level
+			 * than "quit = 1;" in the previous line.
+			 */
+			break;
 		}
 		if (e.type == FocusIn) {
 			focus = True;
