@@ -1,21 +1,22 @@
-/* 
+/*
  * WindowMaker interface definitions
- * 
- * Copyright (C) 1997 Alfredo K. Kojima
- *  
+ *
+ * Copyright (C) 1997-2003 Alfredo K. Kojima
+ *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
  *  License as published by the Free Software Foundation; either
  *  version 2 of the License, or (at your option) any later version.
- *  
+ *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *  Library General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  */
 
 #ifndef _WMLIB_H_
@@ -27,6 +28,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xmd.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 typedef struct {
     CARD32 flags;
     CARD32 window_style;
@@ -62,21 +67,41 @@ typedef struct {
 #define WMFHideApplication		12
 
 
-#if !defined(_NSWindow_h_) && !defined(_GNUstep_H_GUITypes)
+#ifndef _DEFINED_GNUSTEP_WINDOW_INFO
+#define	_DEFINED_GNUSTEP_WINDOW_INFO
+/*
+ * Window levels are taken from GNUstep (gui/AppKit/NSWindow.h)
+ * NSDesktopWindowLevel intended to be the level at which things
+ * on the desktop sit ... so you should be able
+ * to put a desktop background just below it.
+ *
+ * Applications are actually permitted to use any value in the
+ * range INT_MIN+1 to INT_MAX
+ */
 enum {
-  NSNormalWindowLevel   = 0,
-  NSFloatingWindowLevel  = 3,
-  NSDockWindowLevel   = 5,
-  NSSubmenuWindowLevel  = 10,
-  NSMainMenuWindowLevel  = 20
+    WMDesktopWindowLevel = -1000, /* GNUstep addition     */
+    WMNormalWindowLevel = 0,
+    WMFloatingWindowLevel = 3,
+    WMSubmenuWindowLevel = 3,
+    WMTornOffMenuWindowLevel = 3,
+    WMMainMenuWindowLevel = 20,
+    WMDockWindowLevel = 21,       /* Deprecated - use NSStatusWindowLevel */
+    WMStatusWindowLevel = 21,
+    WMModalPanelWindowLevel = 100,
+    WMPopUpMenuWindowLevel = 101,
+    WMScreenSaverWindowLevel = 1000
 };
 
+
+/* window attributes */
 enum {
-  NSBorderlessWindowMask = 0,
-  NSTitledWindowMask = 1,
-  NSClosableWindowMask = 2,
-  NSMiniaturizableWindowMask = 4,
-  NSResizableWindowMask = 8
+    WMBorderlessWindowMask = 0,
+    WMTitledWindowMask = 1,
+    WMClosableWindowMask = 2,
+    WMMiniaturizableWindowMask = 4,
+    WMResizableWindowMask = 8,
+    WMIconWindowMask = 64,
+    WMMiniWindowMask = 128
 };
 #endif
 
@@ -92,7 +117,7 @@ int WMProcessEvent(WMAppContext *app, XEvent *event);
 
 
 WMAppContext *WMAppCreateWithMain(Display *display, int screen_number,
-				  Window main_window);
+                                  Window main_window);
 
 WMAppContext *WMAppCreate(Display *display, int screen_number);
 
@@ -104,8 +129,8 @@ int WMAppSetMainMenu(WMAppContext *app, WMMenu *menu);
 int WMRealizeMenus(WMAppContext *app);
 
 
-void WMSetWindowAttributes(Display *dpy, Window window, 
-			   GNUstepWMAttributes *attributes);
+void WMSetWindowAttributes(Display *dpy, Window window,
+                           GNUstepWMAttributes *attributes);
 
 
 void WMHideApplication(WMAppContext *app);
@@ -117,10 +142,10 @@ void WMHideOthers(WMAppContext *app);
 WMMenu *WMMenuCreate(WMAppContext *app, char *title);
 
 int WMMenuAddItem(WMMenu *menu, char *text, WMMenuAction action,
-		  void *clientData, WMFreeFunction freedata, char *rtext);
+                  void *clientData, WMFreeFunction freedata, char *rtext);
 
-int WMMenuInsertItem(WMMenu *menu, int index, char *text, 
-		     WMMenuAction *action, char *rtext);
+int WMMenuInsertItem(WMMenu *menu, int index, char *text,
+                     WMMenuAction *action, char *rtext);
 
 int WMMenuRemoveItem(WMMenu *menu, int index);
 
@@ -130,5 +155,8 @@ void WMMenuSetEnabled(WMMenu *menu, int index, int enabled);
 
 void WMMenuDestroy(WMMenu *menu, int submenus);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif
