@@ -3,6 +3,7 @@
  * Raster graphics library
  *
  * Copyright (c) 1997-2003 Alfredo K. Kojima
+ * Copyright (c) 2014 Window Maker Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -33,16 +34,9 @@
 #include <time.h>
 #include <assert.h>
 
-#ifdef USE_PNG
-#include <png.h>
-#endif
-
 #include "wraster.h"
 #include "imgformat.h"
 
-#define	RETRY( x )	do {				\
-				x;			\
-			} while (errno == EINTR);
 
 typedef struct RCachedImage {
 	RImage *image;
@@ -52,18 +46,21 @@ typedef struct RCachedImage {
 } RCachedImage;
 
 /*
- * Size of image cache
+ * Number of image to keep in the cache
  */
 static int RImageCacheSize = -1;
 
+#define IMAGE_CACHE_DEFAULT_NBENTRIES	  8
+#define IMAGE_CACHE_MAXIMUM_NBENTRIES	256
+
 /*
- * Max. size of image to store in cache
+ * Max. size of image (in pixels) to store in the cache
  */
 static int RImageCacheMaxImage = -1;	/* 0 = any size */
 
-#define IMAGE_CACHE_SIZE	8
+#define IMAGE_CACHE_DEFAULT_MAXPIXELS	(64 * 64)
+#define IMAGE_CACHE_MAXIMUM_MAXPIXELS	(256 * 256)
 
-#define IMAGE_CACHE_MAX_IMAGE	64*64
 
 static RCachedImage *RImageCache;
 
@@ -73,12 +70,18 @@ static WRImgFormat identFile(const char *path);
 
 char **RSupportedFileFormats(void)
 {
-	static char *tmp[IM_TYPES + 1];
+	static char *tmp[IM_TYPES + 2];
 	int i = 0;
 
 	/* built-in */
 	tmp[i++] = "XPM";
-	/* built-in */
+	/* built-in PNM here refers to anymap format: PPM, PGM, PBM */
+	tmp[i++] = "PNM";
+	/*
+	 * PPM is a just a sub-type of PNM, but it has to be in the list
+	 * for compatibility with legacy programs that may expect it but
+	 * not the new PNM type
+	 */
 	tmp[i++] = "PPM";
 #ifdef USE_TIFF
 	tmp[i++] = "TIFF";
@@ -91,6 +94,9 @@ char **RSupportedFileFormats(void)
 #endif
 #ifdef USE_GIF
 	tmp[i++] = "GIF";
+#endif
+#ifdef USE_WEBP
+	tmp[i++] = "WEBP";
 #endif
 	tmp[i] = NULL;
 
@@ -102,16 +108,20 @@ static void init_cache(void)
 	char *tmp;
 
 	tmp = getenv("RIMAGE_CACHE");
-	if (!tmp || sscanf(tmp, "%i", &RImageCacheSize) != 1) {
-		RImageCacheSize = IMAGE_CACHE_SIZE;
-	}
+	if (!tmp || sscanf(tmp, "%i", &RImageCacheSize) != 1)
+		RImageCacheSize = IMAGE_CACHE_DEFAULT_NBENTRIES;
 	if (RImageCacheSize < 0)
 		RImageCacheSize = 0;
+	if (RImageCacheSize > IMAGE_CACHE_MAXIMUM_NBENTRIES)
+		RImageCacheSize = IMAGE_CACHE_MAXIMUM_NBENTRIES;
 
 	tmp = getenv("RIMAGE_CACHE_SIZE");
-	if (!tmp || sscanf(tmp, "%i", &RImageCacheMaxImage) != 1) {
-		RImageCacheMaxImage = IMAGE_CACHE_MAX_IMAGE;
-	}
+	if (!tmp || sscanf(tmp, "%i", &RImageCacheMaxImage) != 1)
+		RImageCacheMaxImage = IMAGE_CACHE_DEFAULT_MAXPIXELS;
+	if (RImageCacheMaxImage < 0)
+		RImageCacheMaxImage = 0;
+	if (RImageCacheMaxImage > IMAGE_CACHE_MAXIMUM_MAXPIXELS)
+		RImageCacheMaxImage = IMAGE_CACHE_MAXIMUM_MAXPIXELS;
 
 	if (RImageCacheSize > 0) {
 		RImageCache = malloc(sizeof(RCachedImage) * RImageCacheSize);
@@ -123,7 +133,24 @@ static void init_cache(void)
 	}
 }
 
-RImage *RLoadImage(RContext * context, const char *file, int index)
+void RReleaseCache(void)
+{
+	int i;
+
+	if (RImageCacheSize > 0) {
+		for (i = 0; i < RImageCacheSize; i++) {
+			if (RImageCache[i].file) {
+				RReleaseImage(RImageCache[i].image);
+				free(RImageCache[i].file);
+			}
+		}
+		free(RImageCache);
+		RImageCache = NULL;
+		RImageCacheSize = -1;
+	}
+}
+
+RImage *RLoadImage(RContext *context, const char *file, int index)
 {
 	RImage *image = NULL;
 	int i;
@@ -131,9 +158,8 @@ RImage *RLoadImage(RContext * context, const char *file, int index)
 
 	assert(file != NULL);
 
-	if (RImageCacheSize < 0) {
+	if (RImageCacheSize < 0)
 		init_cache();
-	}
 
 	if (RImageCacheSize > 0) {
 
@@ -159,8 +185,16 @@ RImage *RLoadImage(RContext * context, const char *file, int index)
 		return NULL;
 
 	case IM_UNKNOWN:
+#ifdef USE_MAGICK
+		/* generic file format support using ImageMagick
+		 * BMP, PCX, PICT, SVG, ...
+		 */
+		image = RLoadMagick(file);
+		break;
+#else
 		RErrorCode = RERR_BADFORMAT;
 		return NULL;
+#endif
 
 	case IM_XPM:
 		image = RLoadXPM(context, file);
@@ -180,7 +214,7 @@ RImage *RLoadImage(RContext * context, const char *file, int index)
 
 #ifdef USE_JPEG
 	case IM_JPEG:
-		image = RLoadJPEG(context, file);
+		image = RLoadJPEG(file);
 		break;
 #endif				/* USE_JPEG */
 
@@ -190,6 +224,12 @@ RImage *RLoadImage(RContext * context, const char *file, int index)
 		break;
 #endif				/* USE_GIF */
 
+#ifdef USE_WEBP
+	case IM_WEBP:
+		image = RLoadWEBP(file);
+		break;
+#endif				/* USE_WEBP */
+
 	case IM_PPM:
 		image = RLoadPPM(file);
 		break;
@@ -264,6 +304,11 @@ char *RGetImageFileFormat(const char *file)
 		return "GIF";
 #endif				/* USE_GIF */
 
+#ifdef USE_WEBP
+	case IM_WEBP:
+		return "WEBP";
+#endif				/* USE_WEBP */
+
 	case IM_PPM:
 		return "PPM";
 
@@ -280,19 +325,23 @@ static WRImgFormat identFile(const char *path)
 
 	assert(path != NULL);
 
-	RETRY( file = fopen(path, "rb") )
-	if (file == NULL) {
-		RErrorCode = RERR_OPEN;
-		return IM_ERROR;
+	for (;;) {
+		file = fopen(path, "rb");
+		if (file != NULL)
+			break;
+		if (errno != EINTR) {
+			RErrorCode = RERR_OPEN;
+			return IM_ERROR;
+		}
 	}
 
-	RETRY( nread = fread(buffer, 1, sizeof(buffer), file) )
+	nread = fread(buffer, 1, sizeof(buffer), file);
 	if (nread < sizeof(buffer) || ferror(file)) {
-		RETRY( fclose(file) )
+		fclose(file);
 		RErrorCode = RERR_READ;
 		return IM_ERROR;
 	}
-	RETRY( fclose(file) )
+	fclose(file);
 
 	/* check for XPM */
 	if (strncmp((char *)buffer, "/* XPM */", 9) == 0)
@@ -303,14 +352,19 @@ static WRImgFormat identFile(const char *path)
 	    || (buffer[0] == 'M' && buffer[1] == 'M' && buffer[2] == 0 && buffer[3] == '*'))
 		return IM_TIFF;
 
-#ifdef USE_PNG
-	/* check for PNG */
-	if (!png_sig_cmp(buffer, 0, 8))
+	/*
+	 * check for PNG
+	 *
+	 * The signature is defined in the PNG specifiation:
+	 * http://www.libpng.org/pub/png/spec/1.2/PNG-Structure.html
+	 * it is valid for v1.0, v1.1, v1.2 and ISO version
+	 */
+	if (buffer[0] == 137 && buffer[1] == 80 && buffer[2] == 78 && buffer[3] == 71 &&
+	    buffer[4] ==  13 && buffer[5] == 10 && buffer[6] == 26 && buffer[7] == 10)
 		return IM_PNG;
-#endif
 
-	/* check for raw PPM or PGM */
-	if (buffer[0] == 'P' && (buffer[1] == '5' || buffer[1] == '6'))
+	/* check for PBM or PGM or PPM */
+	if (buffer[0] == 'P' && (buffer[1] > '0' && buffer[1] < '7') && (buffer[2] == 0x0a || buffer[2] == 0x20 || buffer[2] == 0x09 || buffer[2] == 0x0d))
 		return IM_PPM;
 
 	/* check for JPEG */
@@ -318,8 +372,18 @@ static WRImgFormat identFile(const char *path)
 		return IM_JPEG;
 
 	/* check for GIF */
-	if (buffer[0] == 'G' && buffer[1] == 'I' && buffer[2] == 'F')
+	if (buffer[0] == 'G' && buffer[1] == 'I' && buffer[2] == 'F' && buffer[3] == '8' &&
+	    (buffer[4] == '7' ||  buffer[4] == '9') && buffer[5] == 'a')
 		return IM_GIF;
 
+	/* check for WEBP */
+	if (buffer[0]  == 'R' && buffer[1]  == 'I' && buffer[2]  == 'F' && buffer[3]  == 'F' &&
+	    buffer[8]  == 'W' && buffer[9]  == 'E' && buffer[10] == 'B' && buffer[11] == 'P' &&
+	    buffer[12] == 'V' && buffer[13] == 'P' && buffer[14] == '8' &&
+	    (buffer[15] == ' '       /* Simple File Format (Lossy) */
+	     || buffer[15] == 'L'    /* Simple File Format (Lossless) */
+	     || buffer[15] == 'X'))  /* Extended File Format */
+		return IM_WEBP;
+
 	return IM_UNKNOWN;
 }
